@@ -61,36 +61,14 @@
 
 #include <sys/types.h>
 #include <sys/stat.h>
+#include <string.h>
 #include <fcntl.h>
+#include <sys/wait.h>
 #include <stdio.h>
 #include <unistd.h>
 #include <setjmp.h>
 #include <signal.h>
 
-#if HAVE_STRING_H
-#include <string.h>
-#else
-#include <strings.h>
-#endif
-
-#if HAVE_SYS_WAIT_H || HAVE_BSD_WAITPID
-#  include <sys/wait.h>
-#endif
-#ifndef WEXITSTATUS
-#  define WEXITSTATUS(stat_val)    (0)
-#endif
-#ifndef WIFEXITED
-#  define WIFEXITED(stat_val)      (1)
-#endif
-
-#ifdef __GNUC__
-#  define alloc __builtin_alloca
-#else
-#  if HAVE_ALLOCA_H
-#    include <alloca.h>
-#  endif
-#endif
-
 #include "proto_decl.h"
 
 #include "BR_Global.h"
@@ -350,9 +328,9 @@ BR_InfoHandler      BR_info_handler = BR_Null;
 
 static jmp_buf      BR_env;
 
-static RETSIGTYPE (*BR_sigill_handler)  ();
-static RETSIGTYPE (*BR_sigbus_handler)  ();
-static RETSIGTYPE (*BR_sigsegv_handler) ();
+static void (*BR_sigill_handler)  ();
+static void (*BR_sigbus_handler)  ();
+static void (*BR_sigsegv_handler) ();
 
 
    /*-----------------------------------------------------------------------*/
@@ -531,23 +509,23 @@ static const short yyrhs[] = {    -1,
 
 #if YYDEBUG != 0
 static const short yyrline[] = { 0,
-   383,   385,   388,   391,   393,   396,   398,   401,   403,   406,
-   411,   417,   419,   421,   423,   425,   433,   434,   435,   436,
-   443,   445,   447,   449,   457,   467,   478,   483,   494,   499,
-   510,   512,   514,   522,   524,   524,   526,   526,   534,   535,
-   536,   537,   538,   539,   545,   550,   562,   564,   572,   574,
-   582,   587,   592,   603,   605,   613,   615,   622,   626,   633,
-   646,   648,   661,   663,   665,   672,   674,   676,   683,   685,
-   687,   700,   708,   716,   724,   729,   733,   741,   749,   757,
-   762,   766,   775,   784,   793,   799,   807,   818,   820,   827,
-   834,   839,   841,   848,   855,   866,   868,   875,   877,   891,
-   893,   895,   897,   899,   906,   912,   923,   929,   942,   944,
-   946,   948,   950,   954,   962,   964,   971,   984,   986,   988,
-   996,  1001,  1003,  1008,  1013,  1024,  1030,  1037,  1044,  1050,
-  1056,  1062,  1068,  1074,  1086,  1091,  1096,  1101,  1112,  1113,
-  1116,  1118,  1118,  1124,  1126,  1132,  1134,  1136,  1137,  1138,
-  1139,  1140,  1146,  1148,  1155,  1157,  1165,  1173,  1184,  1195,
-  1197,  1199,  1201,  1203,  1206,  1214,  1216,  1218
+   361,   363,   366,   369,   371,   374,   376,   379,   381,   384,
+   389,   395,   397,   399,   401,   403,   411,   412,   413,   414,
+   421,   423,   425,   427,   435,   445,   456,   461,   472,   477,
+   488,   490,   492,   500,   502,   502,   504,   504,   512,   513,
+   514,   515,   516,   517,   523,   528,   540,   542,   550,   552,
+   560,   565,   570,   581,   583,   591,   593,   600,   604,   611,
+   624,   626,   639,   641,   643,   650,   652,   654,   661,   663,
+   665,   678,   686,   694,   702,   707,   711,   719,   727,   735,
+   740,   744,   753,   762,   771,   777,   785,   796,   798,   805,
+   812,   817,   819,   826,   833,   844,   846,   853,   855,   869,
+   871,   873,   875,   877,   884,   890,   901,   907,   920,   922,
+   924,   926,   928,   932,   940,   942,   949,   962,   964,   966,
+   974,   979,   981,   986,   991,  1002,  1008,  1015,  1022,  1028,
+  1034,  1040,  1046,  1052,  1064,  1069,  1074,  1079,  1090,  1091,
+  1094,  1096,  1096,  1102,  1104,  1110,  1112,  1114,  1115,  1116,
+  1117,  1118,  1124,  1126,  1133,  1135,  1143,  1151,  1162,  1173,
+  1175,  1177,  1179,  1181,  1184,  1192,  1194,  1196
 };
 #endif
 
@@ -1340,89 +1318,89 @@ yyreduce:
   switch (yyn) {
 
 case 1:
-#line 384 "BR_Parser.y"
+#line 362 "BR_Parser.y"
 { BR_lex_save_state(); ;
     break;}
 case 2:
-#line 386 "BR_Parser.y"
+#line 364 "BR_Parser.y"
 { BR_lex_empty_frame(); ;
     break;}
 case 3:
-#line 389 "BR_Parser.y"
+#line 367 "BR_Parser.y"
 { BR_lex_empty_frame(); ;
     break;}
 case 4:
-#line 392 "BR_Parser.y"
+#line 370 "BR_Parser.y"
 { BR_lex_empty_frame(); ;
     break;}
 case 5:
-#line 394 "BR_Parser.y"
+#line 372 "BR_Parser.y"
 { CLEAR_TEMPLATE(); ;
     break;}
 case 6:
-#line 397 "BR_Parser.y"
+#line 375 "BR_Parser.y"
 {  BR_lex_empty_frame(); ;
     break;}
 case 7:
-#line 399 "BR_Parser.y"
+#line 377 "BR_Parser.y"
 { CLEAR_TEMPLATE(); ;
     break;}
 case 8:
-#line 402 "BR_Parser.y"
+#line 380 "BR_Parser.y"
 { BR_lex_empty_frame(); ;
     break;}
 case 9:
-#line 404 "BR_Parser.y"
+#line 382 "BR_Parser.y"
 { CLEAR_TEMPLATE(); ;
     break;}
 case 10:
-#line 407 "BR_Parser.y"
+#line 385 "BR_Parser.y"
 {
           BR_format_SU(yyvsp[-1], (default_token->_bits | yyvsp[-1]->_bits));
           BR_lex_empty_frame();
         ;
     break;}
 case 11:
-#line 412 "BR_Parser.y"
+#line 390 "BR_Parser.y"
 {
           BR_format_SU(yyvsp[-1], (default_token->_bits | yyvsp[-1]->_bits));
           CLEAR_TEMPLATE();
         ;
     break;}
 case 13:
-#line 420 "BR_Parser.y"
+#line 398 "BR_Parser.y"
 { CLEAR_TEMPLATE();     BR_lex_synchronize(); ;
     break;}
 case 14:
-#line 422 "BR_Parser.y"
+#line 400 "BR_Parser.y"
 { CLEAR_TEMPLATE();     BR_lex_synchronize(); ;
     break;}
 case 15:
-#line 424 "BR_Parser.y"
+#line 402 "BR_Parser.y"
 { BR_lex_empty_frame(); BR_lex_synchronize(); ;
     break;}
 case 16:
-#line 426 "BR_Parser.y"
+#line 404 "BR_Parser.y"
 { BR_lex_empty_frame(); BR_lex_synchronize(); ;
     break;}
 case 21:
-#line 444 "BR_Parser.y"
+#line 422 "BR_Parser.y"
 { BR_format_SU(yyvsp[-1], (default_token->_bits | yyvsp[0]->_bits)); ;
     break;}
 case 22:
-#line 446 "BR_Parser.y"
+#line 424 "BR_Parser.y"
 { BR_format_SU(yyvsp[-1], (default_token->_bits | yyvsp[0]->_bits)); ;
     break;}
 case 23:
-#line 448 "BR_Parser.y"
+#line 426 "BR_Parser.y"
 { BR_format_SU(yyvsp[-1], (default_token->_bits | yyvsp[0]->_bits)); ;
     break;}
 case 24:
-#line 450 "BR_Parser.y"
+#line 428 "BR_Parser.y"
 { BR_format_SU(yyvsp[-1], (default_token->_bits | yyvsp[0]->_bits)); ;
     break;}
 case 25:
-#line 458 "BR_Parser.y"
+#line 436 "BR_Parser.y"
 {
           if (TEST_BITS(default_token->_bits, BR_INFO_EXTERN))
           {
@@ -1434,81 +1412,81 @@ case 25:
         ;
     break;}
 case 26:
-#line 468 "BR_Parser.y"
+#line 446 "BR_Parser.y"
 {
           default_token = BR_lex_unstack_frame();
           CLEAR_BITS(default_token->_bits, BR_INFO_EXTERN);
         ;
     break;}
 case 27:
-#line 479 "BR_Parser.y"
+#line 457 "BR_Parser.y"
 {
           yyvsp[-1]->_line_num = prefix_stamp++;
 	  yyval = APPEND2(yyvsp[-1], yyvsp[0]);
         ;
     break;}
 case 28:
-#line 484 "BR_Parser.y"
+#line 462 "BR_Parser.y"
 {
           yyvsp[-1]->_line_num = yyvsp[-2]->_line_num;
           yyval = APPEND3(yyvsp[-2], yyvsp[-1], yyvsp[0]);
         ;
     break;}
 case 29:
-#line 495 "BR_Parser.y"
+#line 473 "BR_Parser.y"
 {
           yyvsp[0]->_prefix = BR_Null;
           yyval = yyvsp[0];
 	;
     break;}
 case 30:
-#line 500 "BR_Parser.y"
+#line 478 "BR_Parser.y"
 {
           yyvsp[0]->_prefix = yyvsp[-1];
           yyval = yyvsp[0];
         ;
     break;}
 case 31:
-#line 511 "BR_Parser.y"
+#line 489 "BR_Parser.y"
 { yyval = BR_Null; ;
     break;}
 case 32:
-#line 513 "BR_Parser.y"
+#line 491 "BR_Parser.y"
 { yyval = &tmp_token; ;
     break;}
 case 33:
-#line 515 "BR_Parser.y"
+#line 493 "BR_Parser.y"
 { yyval = &tmp_token; ;
     break;}
 case 34:
-#line 523 "BR_Parser.y"
+#line 501 "BR_Parser.y"
 { yyval = &tmp_token; yyval->_bits = (BR_INFO_PROC | BR_INFO_DEF); ;
     break;}
 case 35:
-#line 524 "BR_Parser.y"
+#line 502 "BR_Parser.y"
 { BR_lex_ignore_proc_tail(); ;
     break;}
 case 36:
-#line 525 "BR_Parser.y"
+#line 503 "BR_Parser.y"
 { yyval = &tmp_token; yyval->_bits = (BR_INFO_PROC | BR_INFO_DEF); ;
     break;}
 case 37:
-#line 526 "BR_Parser.y"
+#line 504 "BR_Parser.y"
 { BR_lex_ignore_proc_tail(); ;
     break;}
 case 38:
-#line 527 "BR_Parser.y"
+#line 505 "BR_Parser.y"
 { yyval = &tmp_token; yyval->_bits = (BR_INFO_PROC | BR_INFO_DEF | BR_INFO_C); ;
     break;}
 case 45:
-#line 546 "BR_Parser.y"
+#line 524 "BR_Parser.y"
 {
           template_flag = BR_TRUE;
           template_args = BR_Null;
         ;
     break;}
 case 46:
-#line 551 "BR_Parser.y"
+#line 529 "BR_Parser.y"
 { 
           template_flag = BR_TRUE;
           template_args = yyvsp[-1];
@@ -1516,56 +1494,56 @@ case 46:
         ;
     break;}
 case 47:
-#line 563 "BR_Parser.y"
+#line 541 "BR_Parser.y"
 { yyval = yyvsp[0]; ;
     break;}
 case 48:
-#line 565 "BR_Parser.y"
+#line 543 "BR_Parser.y"
 { yyval = APPEND2(yyvsp[-1], yyvsp[0]); ;
     break;}
 case 49:
-#line 573 "BR_Parser.y"
+#line 551 "BR_Parser.y"
 { yyval = yyvsp[0]; ;
     break;}
 case 50:
-#line 575 "BR_Parser.y"
+#line 553 "BR_Parser.y"
 { yyval = CONVERT_BASIC(yyvsp[0]); ;
     break;}
 case 51:
-#line 583 "BR_Parser.y"
+#line 561 "BR_Parser.y"
 {
           yyval = yyvsp[0];
           yyval->_bits = BR_INFO_CLASS;
         ;
     break;}
 case 52:
-#line 588 "BR_Parser.y"
+#line 566 "BR_Parser.y"
 {
           yyval = yyvsp[0];
           yyval->_bits = BR_INFO_STRUCT;
         ;
     break;}
 case 53:
-#line 593 "BR_Parser.y"
+#line 571 "BR_Parser.y"
 {
           yyval = yyvsp[0];
           yyval->_bits = BR_INFO_UNION;
         ;
     break;}
 case 54:
-#line 604 "BR_Parser.y"
+#line 582 "BR_Parser.y"
 { yyval = yyvsp[0]; ;
     break;}
 case 55:
-#line 606 "BR_Parser.y"
+#line 584 "BR_Parser.y"
 { yyval = yyvsp[-1]; SET_BITS(yyval->_bits, yyvsp[0]->_bits); ;
     break;}
 case 56:
-#line 614 "BR_Parser.y"
+#line 592 "BR_Parser.y"
 { yyval = APPEND2(yyvsp[-1], yyvsp[0]); ;
     break;}
 case 57:
-#line 616 "BR_Parser.y"
+#line 594 "BR_Parser.y"
 { 
           yyval = ((TEST_BITS(yyvsp[-2]->_bits, BR_INFO_CONST))
 		  ? (alloc_token = ALLOC_TOKEN(T_CONST, STR_CONST),
@@ -1574,13 +1552,13 @@ case 57:
         ;
     break;}
 case 58:
-#line 623 "BR_Parser.y"
+#line 601 "BR_Parser.y"
 { 
           yyval = APPEND3(yyvsp[-2], yyvsp[-1], yyvsp[0]);
         ;
     break;}
 case 59:
-#line 627 "BR_Parser.y"
+#line 605 "BR_Parser.y"
 { 
           yyval = ((TEST_BITS(yyvsp[-4]->_bits, BR_INFO_CONST))
 		  ? (alloc_token = ALLOC_TOKEN(T_CONST, STR_CONST),
@@ -1589,7 +1567,7 @@ case 59:
         ;
     break;}
 case 60:
-#line 634 "BR_Parser.y"
+#line 612 "BR_Parser.y"
 { 
           yyval = ((TEST_BITS(yyvsp[-3]->_bits, BR_INFO_CONST))
 		  ? (alloc_token = ALLOC_TOKEN(T_CONST, STR_CONST),
@@ -1598,11 +1576,11 @@ case 60:
         ;
     break;}
 case 61:
-#line 647 "BR_Parser.y"
+#line 625 "BR_Parser.y"
 { yyval = yyvsp[-1]; ;
     break;}
 case 62:
-#line 649 "BR_Parser.y"
+#line 627 "BR_Parser.y"
 {
           yyval = ((TEST_BITS(yyvsp[-2]->_bits, BR_INFO_CONST))
 		  ? (alloc_token = ALLOC_TOKEN(T_CONST, STR_CONST),
@@ -1611,15 +1589,15 @@ case 62:
         ;
     break;}
 case 63:
-#line 662 "BR_Parser.y"
+#line 640 "BR_Parser.y"
 { yyval = yyvsp[0]; ;
     break;}
 case 64:
-#line 664 "BR_Parser.y"
+#line 642 "BR_Parser.y"
 { yyval = yyvsp[0]; ;
     break;}
 case 65:
-#line 666 "BR_Parser.y"
+#line 644 "BR_Parser.y"
 {
           if (template_args != BR_Null)
             BR_replace_template_args(yyvsp[0]);
@@ -1627,15 +1605,15 @@ case 65:
         ;
     break;}
 case 66:
-#line 673 "BR_Parser.y"
+#line 651 "BR_Parser.y"
 { yyval = APPEND2(SPACE(yyvsp[-1]), yyvsp[0]); ;
     break;}
 case 67:
-#line 675 "BR_Parser.y"
+#line 653 "BR_Parser.y"
 { yyval = APPEND2(SPACE(yyvsp[-1]), yyvsp[0]); ;
     break;}
 case 68:
-#line 677 "BR_Parser.y"
+#line 655 "BR_Parser.y"
 {
           if (template_args != BR_Null)
             BR_replace_template_args(yyvsp[-1]);
@@ -1643,15 +1621,15 @@ case 68:
         ;
     break;}
 case 69:
-#line 684 "BR_Parser.y"
+#line 662 "BR_Parser.y"
 { yyval = yyvsp[-1]; ;
     break;}
 case 70:
-#line 686 "BR_Parser.y"
+#line 664 "BR_Parser.y"
 { yyval = yyvsp[-1]; ;
     break;}
 case 71:
-#line 688 "BR_Parser.y"
+#line 666 "BR_Parser.y"
 {
           if (template_args != BR_Null)
             BR_replace_template_args(yyvsp[-1]);
@@ -1659,7 +1637,7 @@ case 71:
         ;
     break;}
 case 72:
-#line 701 "BR_Parser.y"
+#line 679 "BR_Parser.y"
 {
           yyval = ((TEST_BITS(yyvsp[0]->_bits, BR_INFO_CONST))
 		  ? (alloc_token = ALLOC_TOKEN(T_CONST, STR_CONST),
@@ -1669,7 +1647,7 @@ case 72:
         ;
     break;}
 case 73:
-#line 709 "BR_Parser.y"
+#line 687 "BR_Parser.y"
 {
           yyval = ((TEST_BITS(yyvsp[0]->_bits, BR_INFO_CONST))
 		  ? (alloc_token = ALLOC_TOKEN(T_CONST, STR_CONST),
@@ -1679,7 +1657,7 @@ case 73:
         ;
     break;}
 case 74:
-#line 717 "BR_Parser.y"
+#line 695 "BR_Parser.y"
 {
           yyval = ((TEST_BITS(yyvsp[-1]->_bits, BR_INFO_CONST))
 		  ? (alloc_token = ALLOC_TOKEN(T_CONST, STR_CONST),
@@ -1689,18 +1667,18 @@ case 74:
         ;
     break;}
 case 75:
-#line 725 "BR_Parser.y"
+#line 703 "BR_Parser.y"
 {
           yyval = CORRECT_VAL(yyvsp[0], STR_FCT_PT);
           SET_PRECED(yyval, F_PRECED);
         ;
     break;}
 case 76:
-#line 730 "BR_Parser.y"
+#line 708 "BR_Parser.y"
 { yyval = yyvsp[0]; SET_PRECED(yyval, T_PRECED); ;
     break;}
 case 77:
-#line 734 "BR_Parser.y"
+#line 712 "BR_Parser.y"
 {
           yyval = ((TEST_BITS(yyvsp[-1]->_bits, BR_INFO_CONST))
 		  ? (alloc_token = ALLOC_TOKEN(T_CONST, STR_CONST),
@@ -1710,7 +1688,7 @@ case 77:
         ;
     break;}
 case 78:
-#line 742 "BR_Parser.y"
+#line 720 "BR_Parser.y"
 {
           yyval = ((TEST_BITS(yyvsp[-1]->_bits, BR_INFO_CONST))
 		  ? (alloc_token = ALLOC_TOKEN(T_CONST, STR_CONST),
@@ -1720,7 +1698,7 @@ case 78:
         ;
     break;}
 case 79:
-#line 750 "BR_Parser.y"
+#line 728 "BR_Parser.y"
 {
           yyval = ((TEST_BITS(yyvsp[-2]->_bits, BR_INFO_CONST))
 		  ? (alloc_token = ALLOC_TOKEN(T_CONST, STR_CONST),
@@ -1730,18 +1708,18 @@ case 79:
         ;
     break;}
 case 80:
-#line 758 "BR_Parser.y"
+#line 736 "BR_Parser.y"
 {
           yyval = CORRECT_VAL(yyvsp[0], STR_FCT_PT);
           SET_PRECED(yyval, F_PRECED);
         ;
     break;}
 case 81:
-#line 763 "BR_Parser.y"
+#line 741 "BR_Parser.y"
 { yyval = yyvsp[0]; SET_PRECED(yyval, T_PRECED); ;
     break;}
 case 82:
-#line 767 "BR_Parser.y"
+#line 745 "BR_Parser.y"
 {
           TEST_PRECED(yyvsp[0], S_PRECED);
           yyval = ((TEST_BITS(yyvsp[-1]->_bits, BR_INFO_CONST))
@@ -1752,7 +1730,7 @@ case 82:
         ;
     break;}
 case 83:
-#line 776 "BR_Parser.y"
+#line 754 "BR_Parser.y"
 {
           TEST_PRECED(yyvsp[0], A_PRECED);
           yyval = ((TEST_BITS(yyvsp[-1]->_bits, BR_INFO_CONST))
@@ -1763,7 +1741,7 @@ case 83:
         ;
     break;}
 case 84:
-#line 785 "BR_Parser.y"
+#line 763 "BR_Parser.y"
 {
           TEST_PRECED(yyvsp[0], P_PRECED);
           yyval = ((TEST_BITS(yyvsp[-2]->_bits, BR_INFO_CONST))
@@ -1774,7 +1752,7 @@ case 84:
         ;
     break;}
 case 85:
-#line 794 "BR_Parser.y"
+#line 772 "BR_Parser.y"
 {
           TEST_PRECED(yyvsp[-1], F_PRECED);
           yyval = APPEND2(yyvsp[-1], yyvsp[0]);
@@ -1782,7 +1760,7 @@ case 85:
         ;
     break;}
 case 86:
-#line 800 "BR_Parser.y"
+#line 778 "BR_Parser.y"
 {
           TEST_PRECED(yyvsp[-1], T_PRECED);
           yyval = APPEND2(yyvsp[-1], yyvsp[0]);
@@ -1790,18 +1768,18 @@ case 86:
         ;
     break;}
 case 87:
-#line 808 "BR_Parser.y"
+#line 786 "BR_Parser.y"
 {
           yyval = APPEND3(yyvsp[-2], yyvsp[-1], yyvsp[0]);
           SET_PRECED(yyval, GET_PRECED(yyvsp[-1]));
         ;
     break;}
 case 88:
-#line 819 "BR_Parser.y"
+#line 797 "BR_Parser.y"
 { BR_format_SU(yyvsp[-1], default_token->_bits | BR_INFO_DATA); ;
     break;}
 case 89:
-#line 821 "BR_Parser.y"
+#line 799 "BR_Parser.y"
 {
           if (global_prefix != BR_Null)         
             BR_format_SU(yyvsp[-1], default_token->_bits | BR_INFO_DATA);
@@ -1810,7 +1788,7 @@ case 89:
         ;
     break;}
 case 90:
-#line 828 "BR_Parser.y"
+#line 806 "BR_Parser.y"
 {
           if ((yyvsp[0] != BR_Null) && ((yyvsp[-1]->_bits & BR_INFO_PROC) != 0))
             BR_format_SU(yyvsp[-1], (default_token->_bits | BR_INFO_PURE));
@@ -1819,18 +1797,18 @@ case 90:
         ;
     break;}
 case 91:
-#line 835 "BR_Parser.y"
+#line 813 "BR_Parser.y"
 {
           if (global_prefix == BR_Null)
             BR_YYERROR;
         ;
     break;}
 case 92:
-#line 840 "BR_Parser.y"
+#line 818 "BR_Parser.y"
 { BR_format_SU(yyvsp[-1], default_token->_bits | BR_INFO_DATA); ;
     break;}
 case 93:
-#line 842 "BR_Parser.y"
+#line 820 "BR_Parser.y"
 {
           if (global_prefix != BR_Null)         
             BR_format_SU(yyvsp[-1], default_token->_bits | BR_INFO_DATA);
@@ -1839,7 +1817,7 @@ case 93:
         ;
     break;}
 case 94:
-#line 849 "BR_Parser.y"
+#line 827 "BR_Parser.y"
 {
           if ((yyvsp[0] != BR_Null) && ((yyvsp[-1]->_bits & BR_INFO_PROC) != 0))
             BR_format_SU(yyvsp[-1], (default_token->_bits | BR_INFO_PURE));
@@ -1848,18 +1826,18 @@ case 94:
         ;
     break;}
 case 95:
-#line 856 "BR_Parser.y"
+#line 834 "BR_Parser.y"
 {
           if (global_prefix == BR_Null)
             BR_YYERROR;
         ;
     break;}
 case 96:
-#line 867 "BR_Parser.y"
+#line 845 "BR_Parser.y"
 { BR_format_SU(yyvsp[-1], default_token->_bits | BR_INFO_DATA); ;
     break;}
 case 97:
-#line 869 "BR_Parser.y"
+#line 847 "BR_Parser.y"
 {
           if ((yyvsp[0] != BR_Null) && ((yyvsp[-1]->_bits & BR_INFO_PROC) != 0))
             BR_format_SU(yyvsp[-1], (default_token->_bits | BR_INFO_PURE));
@@ -1868,11 +1846,11 @@ case 97:
         ;
     break;}
 case 98:
-#line 876 "BR_Parser.y"
+#line 854 "BR_Parser.y"
 { BR_format_SU(yyvsp[-1], default_token->_bits | BR_INFO_DATA); ;
     break;}
 case 99:
-#line 878 "BR_Parser.y"
+#line 856 "BR_Parser.y"
 {
           if ((yyvsp[0] != BR_Null) && ((yyvsp[-1]->_bits & BR_INFO_PROC) != 0))
             BR_format_SU(yyvsp[-1], (default_token->_bits | BR_INFO_PURE));
@@ -1881,23 +1859,23 @@ case 99:
         ;
     break;}
 case 100:
-#line 892 "BR_Parser.y"
+#line 870 "BR_Parser.y"
 { yyval = yyvsp[0]; yyval->_bits = BR_INFO_DATA; ;
     break;}
 case 101:
-#line 894 "BR_Parser.y"
+#line 872 "BR_Parser.y"
 { yyval = yyvsp[0]; yyval->_bits = BR_INFO_DATA; ;
     break;}
 case 102:
-#line 896 "BR_Parser.y"
+#line 874 "BR_Parser.y"
 { yyval = yyvsp[0]; yyval->_bits = BR_INFO_DATA; ;
     break;}
 case 103:
-#line 898 "BR_Parser.y"
+#line 876 "BR_Parser.y"
 { yyval = yyvsp[-1]; yyval->_bits = BR_INFO_DATA; ;
     break;}
 case 104:
-#line 900 "BR_Parser.y"
+#line 878 "BR_Parser.y"
 {
           yyval = APPEND2(yyvsp[-1], yyvsp[0]);
           SET_BITS(yyval->_bits, BR_INFO_PROC);
@@ -1906,7 +1884,7 @@ case 104:
         ;
     break;}
 case 105:
-#line 907 "BR_Parser.y"
+#line 885 "BR_Parser.y"
 {
           yyvsp[-2]->_prefix = BR_Null;
           yyval = APPEND3(yyvsp[-2], yyvsp[-1], yyvsp[0]);
@@ -1914,7 +1892,7 @@ case 105:
         ;
     break;}
 case 106:
-#line 913 "BR_Parser.y"
+#line 891 "BR_Parser.y"
 {
           yyvsp[-2]->_prefix = BR_Null;
           yyval = ((TEST_BITS(yyvsp[-2]->_bits, BR_INFO_CONST))
@@ -1927,7 +1905,7 @@ case 106:
         ;
     break;}
 case 107:
-#line 924 "BR_Parser.y"
+#line 902 "BR_Parser.y"
 {
           yyvsp[-2]->_prefix = yyvsp[-3];
           yyval = APPEND3(yyvsp[-2], yyvsp[-1], yyvsp[0]);
@@ -1935,7 +1913,7 @@ case 107:
         ;
     break;}
 case 108:
-#line 930 "BR_Parser.y"
+#line 908 "BR_Parser.y"
 {
           yyvsp[-2]->_prefix = yyvsp[-3];
           yyval = ((TEST_BITS(yyvsp[-3]->_bits, BR_INFO_CONST))
@@ -1948,35 +1926,35 @@ case 108:
         ;
     break;}
 case 109:
-#line 943 "BR_Parser.y"
+#line 921 "BR_Parser.y"
 { yyval = yyvsp[0]; ;
     break;}
 case 110:
-#line 945 "BR_Parser.y"
+#line 923 "BR_Parser.y"
 { yyval = yyvsp[0]; ;
     break;}
 case 111:
-#line 947 "BR_Parser.y"
+#line 925 "BR_Parser.y"
 { yyval = yyvsp[0]; ;
     break;}
 case 112:
-#line 949 "BR_Parser.y"
+#line 927 "BR_Parser.y"
 { yyval = yyvsp[-1]; ;
     break;}
 case 113:
-#line 951 "BR_Parser.y"
+#line 929 "BR_Parser.y"
 { yyval = yyvsp[-1]; ;
     break;}
 case 114:
-#line 955 "BR_Parser.y"
+#line 933 "BR_Parser.y"
 { yyval = yyvsp[-1]; ;
     break;}
 case 115:
-#line 963 "BR_Parser.y"
+#line 941 "BR_Parser.y"
 { yyval = yyvsp[0]; ;
     break;}
 case 116:
-#line 965 "BR_Parser.y"
+#line 943 "BR_Parser.y"
 {
           yyval = ((TEST_BITS(yyvsp[0]->_bits, BR_INFO_CONST))
 		  ? (alloc_token = ALLOC_TOKEN(T_CONST, STR_CONST),
@@ -1985,7 +1963,7 @@ case 116:
         ;
     break;}
 case 117:
-#line 972 "BR_Parser.y"
+#line 950 "BR_Parser.y"
 {
           yyval = ((TEST_BITS(yyvsp[0]->_bits, BR_INFO_CONST))
 		  ? (alloc_token = ALLOC_TOKEN(T_CONST, STR_CONST),
@@ -1994,51 +1972,51 @@ case 117:
 	;
     break;}
 case 118:
-#line 985 "BR_Parser.y"
+#line 963 "BR_Parser.y"
 { yyval = yyvsp[0]; ;
     break;}
 case 119:
-#line 987 "BR_Parser.y"
+#line 965 "BR_Parser.y"
 { yyval = yyvsp[0]; ;
     break;}
 case 120:
-#line 989 "BR_Parser.y"
+#line 967 "BR_Parser.y"
 { yyval = yyvsp[0]; ;
     break;}
 case 121:
-#line 997 "BR_Parser.y"
+#line 975 "BR_Parser.y"
 {
           yyval = ALLOC_TOKEN(T_IDENT, STR_ANONYMOUS);
           BR_format_SU(yyval, BR_INFO_DEF | BR_INFO_ENUM | default_token->_bits);
 	;
     break;}
 case 122:
-#line 1002 "BR_Parser.y"
+#line 980 "BR_Parser.y"
 { BR_format_SU(yyvsp[-2], BR_INFO_DEF | BR_INFO_ENUM | default_token->_bits); ;
     break;}
 case 123:
-#line 1004 "BR_Parser.y"
+#line 982 "BR_Parser.y"
 {
           SET_ACCESS(yyvsp[0]->_bits);
           BR_lex_jump_bracket();
         ;
     break;}
 case 124:
-#line 1009 "BR_Parser.y"
+#line 987 "BR_Parser.y"
 {
           UNSTACK_PREFIX();
           default_token = BR_lex_unstack_frame();
         ;
     break;}
 case 125:
-#line 1014 "BR_Parser.y"
+#line 992 "BR_Parser.y"
 {
           UNSTACK_PREFIX();
           default_token = BR_lex_unstack_frame();
         ;
     break;}
 case 126:
-#line 1025 "BR_Parser.y"
+#line 1003 "BR_Parser.y"
 {
           yyval = yyvsp[0];
           STACK_PREFIX(yyvsp[0]);
@@ -2046,7 +2024,7 @@ case 126:
         ;
     break;}
 case 127:
-#line 1031 "BR_Parser.y"
+#line 1009 "BR_Parser.y"
 {
           STACK_PREFIX(yyvsp[0]);
           default_token = BR_lex_stack_frame(BR_INFO_EMPTY);
@@ -2054,11 +2032,11 @@ case 127:
         ;
     break;}
 case 128:
-#line 1037 "BR_Parser.y"
+#line 1015 "BR_Parser.y"
 { yyval = yyvsp[-2]; ;
     break;}
 case 129:
-#line 1045 "BR_Parser.y"
+#line 1023 "BR_Parser.y"
 {
           yyval = ALLOC_TOKEN(T_IDENT, STR_ANONYMOUS);
           BR_format_SU(yyval, BR_INFO_DEF | BR_INFO_CLASS | default_token->_bits);
@@ -2066,7 +2044,7 @@ case 129:
         ;
     break;}
 case 130:
-#line 1051 "BR_Parser.y"
+#line 1029 "BR_Parser.y"
 {
           yyval = ALLOC_TOKEN(T_IDENT, STR_ANONYMOUS);
           BR_format_SU(yyval, BR_INFO_DEF | BR_INFO_STRUCT | default_token->_bits);
@@ -2074,7 +2052,7 @@ case 130:
         ;
     break;}
 case 131:
-#line 1057 "BR_Parser.y"
+#line 1035 "BR_Parser.y"
 {
           yyval = ALLOC_TOKEN(T_IDENT, STR_ANONYMOUS);
           BR_format_SU(yyval, BR_INFO_DEF | BR_INFO_UNION | default_token->_bits);
@@ -2082,7 +2060,7 @@ case 131:
         ;
     break;}
 case 132:
-#line 1063 "BR_Parser.y"
+#line 1041 "BR_Parser.y"
 {
           yyval = yyvsp[0];
           BR_format_SU(yyval, BR_INFO_DEF | BR_INFO_CLASS | default_token->_bits);
@@ -2090,7 +2068,7 @@ case 132:
         ;
     break;}
 case 133:
-#line 1069 "BR_Parser.y"
+#line 1047 "BR_Parser.y"
 {
           yyval = yyvsp[0];
           BR_format_SU(yyval, BR_INFO_DEF | BR_INFO_STRUCT | default_token->_bits);
@@ -2098,7 +2076,7 @@ case 133:
         ;
     break;}
 case 134:
-#line 1075 "BR_Parser.y"
+#line 1053 "BR_Parser.y"
 {
           yyval = yyvsp[0];
           BR_format_SU(yyval, BR_INFO_DEF | BR_INFO_UNION | default_token->_bits);
@@ -2106,74 +2084,74 @@ case 134:
         ;
     break;}
 case 135:
-#line 1087 "BR_Parser.y"
+#line 1065 "BR_Parser.y"
 {
           BR_format_SU(yyvsp[0], (BR_INFO_PARENT|BR_INFO_PRIVATE|default_token->_bits));
           BR_lex_empty_frame();
         ;
     break;}
 case 136:
-#line 1092 "BR_Parser.y"
+#line 1070 "BR_Parser.y"
 {
           BR_format_SU(yyvsp[0], (BR_INFO_PARENT|yyvsp[-1]->_bits|default_token->_bits));
           BR_lex_empty_frame();
         ;
     break;}
 case 137:
-#line 1097 "BR_Parser.y"
+#line 1075 "BR_Parser.y"
 {
           BR_format_SU(yyvsp[0], (BR_INFO_PARENT|BR_INFO_PRIVATE|default_token->_bits));
           BR_lex_empty_frame();
         ;
     break;}
 case 138:
-#line 1102 "BR_Parser.y"
+#line 1080 "BR_Parser.y"
 {
           BR_format_SU(yyvsp[0], (BR_INFO_PARENT|yyvsp[-1]->_bits|default_token->_bits));
           BR_lex_empty_frame();
         ;
     break;}
 case 140:
-#line 1114 "BR_Parser.y"
+#line 1092 "BR_Parser.y"
 { default_token->_bits |= BR_INFO_FRIEND; ;
     break;}
 case 141:
-#line 1116 "BR_Parser.y"
+#line 1094 "BR_Parser.y"
 { BR_lex_empty_frame(); ;
     break;}
 case 143:
-#line 1119 "BR_Parser.y"
+#line 1097 "BR_Parser.y"
 {
           SET_ACCESS(yyvsp[0]->_bits);
           BR_lex_jump_colon();
         ;
     break;}
 case 144:
-#line 1124 "BR_Parser.y"
+#line 1102 "BR_Parser.y"
 { BR_lex_empty_frame(); ;
     break;}
 case 146:
-#line 1133 "BR_Parser.y"
+#line 1111 "BR_Parser.y"
 { BR_format_SU(yyvsp[-1], (default_token->_bits | BR_INFO_TYPEDEF)); ;
     break;}
 case 147:
-#line 1135 "BR_Parser.y"
+#line 1113 "BR_Parser.y"
 { BR_format_SU(yyvsp[-1], (yyvsp[-1]->_bits | default_token->_bits)); ;
     break;}
 case 153:
-#line 1147 "BR_Parser.y"
+#line 1125 "BR_Parser.y"
 { BR_format_SU(yyvsp[-2], (yyvsp[-2]->_bits | default_token->_bits | BR_INFO_DEF)); ;
     break;}
 case 155:
-#line 1156 "BR_Parser.y"
+#line 1134 "BR_Parser.y"
 { BR_format_SU(yyvsp[0], (yyvsp[0]->_bits | default_token->_bits)); ;
     break;}
 case 156:
-#line 1158 "BR_Parser.y"
+#line 1136 "BR_Parser.y"
 { BR_format_SU(yyvsp[0], (yyvsp[0]->_bits | default_token->_bits)); ;
     break;}
 case 157:
-#line 1166 "BR_Parser.y"
+#line 1144 "BR_Parser.y"
 {
           yyval = APPEND2(yyvsp[-1], yyvsp[0]);
           if (TEST_BITS(yyvsp[0]->_last->_bits, BR_INFO_CONST))
@@ -2183,7 +2161,7 @@ case 157:
         ;
     break;}
 case 158:
-#line 1174 "BR_Parser.y"
+#line 1152 "BR_Parser.y"
 {
           yyvsp[-2]->_prefix = BR_Null;
           yyval = ((TEST_BITS(yyvsp[-2]->_bits, BR_INFO_CONST))
@@ -2196,7 +2174,7 @@ case 158:
         ;
     break;}
 case 159:
-#line 1185 "BR_Parser.y"
+#line 1163 "BR_Parser.y"
 {
           yyvsp[-2]->_prefix = yyvsp[-3];
           yyval = ((TEST_BITS(yyvsp[-3]->_bits, BR_INFO_CONST))
@@ -2209,39 +2187,39 @@ case 159:
         ;
     break;}
 case 160:
-#line 1196 "BR_Parser.y"
+#line 1174 "BR_Parser.y"
 { yyval = yyvsp[0]; ;
     break;}
 case 161:
-#line 1198 "BR_Parser.y"
+#line 1176 "BR_Parser.y"
 { yyval = yyvsp[0]; ;
     break;}
 case 162:
-#line 1200 "BR_Parser.y"
+#line 1178 "BR_Parser.y"
 { yyval = yyvsp[0]; ;
     break;}
 case 163:
-#line 1202 "BR_Parser.y"
+#line 1180 "BR_Parser.y"
 { yyval = yyvsp[-1]; ;
     break;}
 case 164:
-#line 1204 "BR_Parser.y"
+#line 1182 "BR_Parser.y"
 { yyval = yyvsp[-1]; ;
     break;}
 case 165:
-#line 1207 "BR_Parser.y"
+#line 1185 "BR_Parser.y"
 { yyval = yyvsp[-1]; ;
     break;}
 case 166:
-#line 1215 "BR_Parser.y"
+#line 1193 "BR_Parser.y"
 { yyval = yyvsp[0]; yyval->_bits = BR_INFO_PRIVATE; ;
     break;}
 case 167:
-#line 1217 "BR_Parser.y"
+#line 1195 "BR_Parser.y"
 { yyval = yyvsp[0]; yyval->_bits = BR_INFO_PROTECTED; ;
     break;}
 case 168:
-#line 1219 "BR_Parser.y"
+#line 1197 "BR_Parser.y"
 { yyval = yyvsp[0]; yyval->_bits = BR_INFO_PUBLIC; ;
     break;}
 }
@@ -2442,7 +2420,7 @@ yyerrhandle:
   yystate = yyn;
   goto yynewstate;
 }
-#line 1223 "BR_Parser.y"
+#line 1201 "BR_Parser.y"
 
 
 
@@ -2806,7 +2784,7 @@ BR_format_SU(SU_tree, default_infos)
 
    /*-----------------------------------------------------------------------*/
 
-static RETSIGTYPE
+static void
 BR_signal_handler()
 {
   longjmp(BR_env, 1);
@@ -2824,7 +2802,7 @@ BR_parse_file(file_name, info_handler, filter_cmd)
   pid_t       child_pid;
   BR_Boolean  parse_ok;
   FILE*       file_pt;
-#if HAVE_BSD_WAITPID
+#ifdef _AIX
   union wait  child_status;
 #else
   int         child_status;
@@ -2895,9 +2873,9 @@ BR_parse_file(file_name, info_handler, filter_cmd)
     BR_info_handler    = info_handler;
     default_token      = BR_lex_stack_frame(BR_INFO_EMPTY);
 
-    BR_sigill_handler  = signal(SIGILL,  BR_signal_handler);
-    BR_sigbus_handler  = signal(SIGBUS,  BR_signal_handler);
-    BR_sigsegv_handler = signal(SIGSEGV, BR_signal_handler);
+    BR_sigill_handler  = (void (*) ()) signal(SIGILL,  BR_signal_handler);
+    BR_sigbus_handler  = (void (*) ()) signal(SIGBUS,  BR_signal_handler);
+    BR_sigsegv_handler = (void (*) ()) signal(SIGSEGV, BR_signal_handler);
 
     if (setjmp(BR_env) == 0)
     {
@@ -2915,27 +2893,19 @@ BR_parse_file(file_name, info_handler, filter_cmd)
       parse_ok = BR_FALSE;
     }
 
-    signal(SIGILL,  BR_sigill_handler);
-    signal(SIGBUS,  BR_sigbus_handler);
-    signal(SIGSEGV, BR_sigsegv_handler);
+    signal(SIGILL,  (void (*) ()) BR_sigill_handler);
+    signal(SIGBUS,  (void (*) ()) BR_sigbus_handler);
+    signal(SIGSEGV, (void (*) ()) BR_sigsegv_handler);
 
     if (file_pt != BR_Null)
       fclose(file_pt);
 
     if (   (child_pid > 0)
-#if HAVE_SYS_WAIT_H || HAVE_BSD_WAITPID
 	&& (   (waitpid(child_pid, &child_status, WUNTRACED) != child_pid)
-#else
-	&& (   (wait(&child_status) != child_pid)
-#endif
 	    || (WIFEXITED(child_status)   == 0)
 	    || (WEXITSTATUS(child_status) != 0)))
       parse_ok = BR_FALSE;
   }
 
-#if C_ALLOCA
-  alloca(0);
-#endif
-
   return(parse_ok);
 }
