@@ -3,20 +3,12 @@
 #include <X11/Xutil.h>
 #include <X11/cursorfont.h>
 
-#if STDC_HEADERS
-#  include <stdlib.h>
+#if defined (apollo) || defined (__FreeBSD__)
+#include <stdlib.h>
 #else
-#  if HAVE_MALLOC_H
-#    include <malloc.h>
-#  endif
+#include <malloc.h>
 #endif
-
-#if HAVE_STRING_H
 #include <string.h>
-#else
-#include <strings.h>
-#endif
-
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <sys/param.h>
@@ -39,10 +31,6 @@
  
 extern Browser br;
 
-#if !HAVE_STRDUP
-extern FCT (char*, strdup, (char*) );
-#endif
-
 /*-------------------------------------------------------------------------
 */
 static ScopeType compute_scope(infos)
@@ -296,14 +284,16 @@ void browser_add(s, rec)
     extern char  *getcwd();
     
     br.parse_flag = (rec) ? RECURSIVE : NO_RECURSIVE;
-#if HAVE_GETCWD
-    (void) getcwd ( pathname, MAXPATHLEN );
-#else
+/*    
+#ifdef linux
     if ( getwd ( pathname ) == 0 ) {
       (void) fprintf ( stderr, "Can't getwd\n" );
       return;
     }
-#endif
+#else	
+*/
+    (void) getcwd ( pathname, MAXPATHLEN );
+/* #endif */
     here = (char *) malloc(strlen(pathname) + 1);
     if (! here) return;
     (void) strcpy (here, pathname);
@@ -311,16 +301,18 @@ void browser_add(s, rec)
     (void) stat ( s, &st );
     if ( S_ISDIR(st.st_mode) != 0 ) {
       (void) chdir(s);
-#if HAVE_GETCWD
-      (void) getcwd ( pathname, MAXPATHLEN );
-#else
+/*      
+#ifdef linux
       if ( getwd ( pathname ) == 0 ) {
 	(void) fprintf ( stderr, "Can't getwd\n" );
 	(void) chdir(here);
 	free(here);
 	return;
       }
-#endif
+#else	
+*/
+      (void) getcwd ( pathname, MAXPATHLEN );
+/* #endif */
       LoadDir ( pathname );
     }
     else if (S_ISREG(st.st_mode) && GoodSuffix (s)) {
