@@ -86,7 +86,7 @@ typedef enum { NO_JMP,
 
 extern int During_Evaluation;
 extern FCT( void, accept_ctrl_c,()	);
-extern FCT( RETSIGTYPE, error_ctrl_c,(int)	);
+extern FCT( void, error_ctrl_c,(int)	);
 extern FCT( void, clear_ctrl_c,()	);
 
 #define ignore_ctrl_c() 		During_Evaluation = 0
