@@ -39,12 +39,7 @@
 
 
 #include <stdio.h>
-
-#if HAVE_STRING_H
 #include <string.h>
-#else
-#include <strings.h>
-#endif
 
 /*#include "error.h"*/
 #include "FunctionCall.h"
