@@ -1,3 +1,10 @@
+/*
+#if ( hpux || _AIX || ultrix || __osf__ || UNIXWARE )
+#else
+extern void *malloc(), *realloc();
+#endif
+*/
+
     /* This file is a transformation of James A. Roskind's C++ grammar */
 
 
