@@ -63,6 +63,8 @@
 #include "input_str.h"
 #include "warn_box.h"
 #include "dial_box.h"
+#include "ie_func.h"
+#include "selection.h"
 
 static char *str_save = 0;
 static char *str_old = 0;
@@ -264,6 +266,11 @@ int HandleGlobal ( text )
     char *start,  *end;
     int f_query = False;
     
+    if (text -> selection -> select == True) {
+      SetCurrentLine (text);
+      ClearSelection(text, True);
+    }
+
     line = text -> no_current_line;
     old_pos = GetNcFromLeft ( text -> buf );
     
@@ -343,6 +350,11 @@ void QueryReplace ( text )
     int abort, modif;
     char c = '\007'; /* ^G */
     
+    if (text -> selection -> select == True){
+      SetCurrentLine (text);
+      ClearSelection(text, True);
+    }
+
     if ( SetReplaceString ( text, QUERY, S_KBD ) == -1 ) return;
     
     start = (char *) RightBuf ( text -> buf ); 
@@ -568,10 +580,15 @@ static char *SetString ( text, prompt, from )
     char c = '\007'; /* ^G */
     int len;
     
+    if (text -> selection -> select == True) {
+      SetCurrentLine (text);
+      ClearSelection(text, True);
+    }
+
     if ( (str_save == 0) || (strlen (str_save)) == 0 ) {
 	if ( from == S_KBD )
 	  str = (char *) GetString ( text, prompt, False );
-	else
+	else 
 	  str = ( char *) GetStringFromDB ( prompt, False );
 	
 	if ( str == 0 )
@@ -918,10 +935,12 @@ int RE_Search ( regex, buffer, size, direction)
 	old_regex = (char*) malloc ((unsigned) strlen(regex) + 1);
 	strcpy (old_regex, regex);
     }
+   
 #ifdef DEBUG
-    (void) fprintf ( stderr, "size = %d range = %d\n reg = %s\n",
-		    size, range, regex );
-#endif DEBUG
+    (void) fprintf ( stderr, "size = %d range = %d\n reg = %s len = %d\n",
+		    size, range, regex, strlen(regex));
+#endif /* DEBUG */
+ 
     search_result = re_search ( &RE_pattern_buffer,
 			       buffer, size, start, range, &RE_registers ); 
 
@@ -948,6 +967,7 @@ void RE_MenuReplace ( text )
 **	Function name : RE_ReplaceMatch
 **
 **	Description : This function is derived from the emacs replace_match
+**                    and has been patched by Michael Andres.
 **	Input :
 **	Output : True if OK
 */
@@ -960,29 +980,68 @@ int RE_ReplaceMatch ( text, newstring )
     
     char *buffer;
 
+    /* MA:
+    ** is recomputed inside the loop in case of \& and \n.
+    **
     re_len = RE_registers.end[0] - RE_registers.start[0];
+    */
     
     /* newstring peut contenir \& ou \n avec 0<n<10.
        \& : substitution par la regex.
        \n : substitution par la substring n de la regex.
     */
     
+    /* MA:
+    ** Since RE_registers.start/end measure from the top of the buffer
+    ** we place the cursor at pos 'RE_registers.start[0]'.
+    **
     ie_goto_char(text, ie_current_position(text) + RE_registers.start[0]);
+    */
+    ie_goto_char(text, RE_registers.start[0]);
+    
     buffer = RightBuf(text->buf); /* On est sur la regex */
     for (i=0;i<new_len;i++) {
 	c = newstring[i];
 	if (c == '\\') {
 	    c = newstring[++i];
 	    if (c == '&') {
+		/* MA:
+                ** Recompute re_len (as the following elseif does too)
+		*/
+		re_len = RE_registers.end[0] - RE_registers.start[0];
+		/**/
 		for(j=0;j<re_len;j++) {
+		    /* MA:
+                    ** Since buffer starts at 'RE_registers.start[0]',
+		    ** we may use a plain 'j'
+		    **
 		    nth_c = RE_registers.start[0]+j;
 		    ie_insert_char (text, buffer[nth_c]);
+		    */
+		    ie_insert_char (text, buffer[j]);
 		}
 	    }
+	    /* MA:
+            ** ??? A little bit unshure. 'RE_registers.num_regs'
+	    ** seems to be '==30' anytime. So allow '1'-'9'.
 	    else if ((c >=1) && (c <= RE_registers.num_regs)) {
+	    */
+	    else if ((c >='1') && (c <= '9')) {
+	        /* MA:
+                ** Since buffer starts at 'RE_registers.start[0]',
+		** we need the offset to 'RE_registers.start[c]'
+		*/
+	        int offset;
+	        c -= '0';
+		offset = RE_registers.start[c] - RE_registers.start[0];
+	        /**/
 		re_len = RE_registers.end[c] - RE_registers.start[c];
 		for(j=0;j<re_len;j++) {
+		    /* MA:
+                    ** Use 'offset'
 		    nth_c = RE_registers.start[0]+j;
+		    */
+		    nth_c = offset+j;
 		    ie_insert_char (text, buffer[nth_c]);
 		}
 	    }
@@ -994,6 +1053,11 @@ int RE_ReplaceMatch ( text, newstring )
 	    ie_insert_char (text,c);
 	}
     }
+    /* MA:
+    ** Recompute re_len.
+    */
+    re_len = RE_registers.end[0] - RE_registers.start[0];
+    /**/
     /* On vire la regex originale */
     for(j=0;j<re_len;j++) {
 	ie_delete_char (text);
