@@ -57,11 +57,13 @@ extern StringTable* get_files_list    ();
 
 extern StringTable* get_classes_list  ();
 
-extern StringTable* get_parents_list  (/* char* class_name */);
+extern StringTable* get_parents_list  (/* char* class_name, int obj */);
 
 extern StringTable* get_sons_list     (/* char* class_name */);
 
-extern StringTable* get_methods_list  (/* char* class_name */);
+extern StringTable* get_methods_list  (/* char* class_name, int cut */);
+
+extern StringTable* get_attributes_list  (/* char* class_name, int cut */);
 
 extern Position*    get_class_decl    (/* char* class_name */);
 
@@ -72,10 +74,17 @@ extern Position*    get_method_impl   (/* char* class_name,
 				                          char* method_name */);
 
 
-extern StringTable* get_procs_list    ();
+extern StringTable* get_procs_list    (/* char * prefix */);
 
 extern Position*    get_proc_impl     (/* char* proc_name */);
 
+extern Position*    get_attribute_decl   (/* char* class_name,
+				                          char* method_name */);
+
+extern StringTable* get_globals_list    (/* char * prefix */);
+
+extern Position*    get_global_impl     (/* char* global_name */);
+
 
 /*------------------------------------------------------------------------------
 //                     Les procedures de gestion du "Browser"
@@ -88,6 +97,7 @@ extern void parse_file   (/* char* file_name */);
 
 extern void delete_file  (/* char* file_name */);
 
+extern void BrowserHide (/* char * selected_class_name */);
 
 #endif  /*  BROWSERENGINE_H  */
 
