@@ -42,25 +42,17 @@
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
 #include <X11/cursorfont.h>
-
-#if STDC_HEADERS
-#  include <stdlib.h>
+#if defined (apollo) || defined (__FreeBSD__)
+#include <stdlib.h>
 #else
-#  if HAVE_MALLOC_H
-#    include <malloc.h>
-#  endif
+#include <malloc.h>
 #endif
-
-#if HAVE_STRING_H
 #include <string.h>
-#else
-#include <strings.h>
-#endif
-
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <X11/Xatom.h>
 
+
 #include "options.h"
 #include "xcoral.h"
 #include "browser_init.h"
@@ -103,10 +95,6 @@ FCT (void, UpdateTitle, (char *name) );
 FCT (void, RefreshPpButton,() );
 FCT (static void, TitleVisit, (char *name) );
 
-#if !HAVE_STRDUP
-extern FCT (char*, strdup, (char*) );
-#endif
-
 /*
 **	Function name : ExposeBrowser
 **
@@ -894,9 +882,8 @@ static int ClassSelect ( bwin )
     br.tbw[W_ATTRIBUTES].select = 0;
     ClearPage ( br.tbw[W_ATTRIBUTES].text );
     FirstPage ( br.tbw[W_ATTRIBUTES].text ); 
-
+    
     tmp = ( char **)  get_parents_list ( class_name, 0);
-    KillText(dpy, br.tbw[W_PARENT].text);
     ExtractInfos ( tmp, W_PARENT );
     if ( tmp != 0 )
       free ( (char *) tmp );
@@ -904,10 +891,9 @@ static int ClassSelect ( bwin )
     br.tbw[W_PARENT].select = 0;
     ClearPage ( br.tbw[W_PARENT].text );
     FirstPage ( br.tbw[W_PARENT].text ); 
-
+    
     FirstPage ( br.tbw[W_CHILD].text );
     tmp = ( char **)  get_sons_list ( class_name);
-    KillText(dpy, br.tbw[W_CHILD].text);
     free(class_name);
     ExtractInfos ( tmp, W_CHILD );
     if ( tmp != 0 )
