@@ -52,40 +52,22 @@
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
 
-#if HAVE_DIRENT_H
-#  include <dirent.h>
-#  define NAMLEN(dirent) strlen((dirent)->d_name)
+#ifdef apollo
+#include <sys/dir.h>
+#define dirent direct
 #else
-#  define dirent direct
-#  define NAMLEN(dirent) (dirent)->d_namlen
-#  if HAVE_SYS_NDIR_H
-#    include <sys/ndir.h>
-#  endif
-#  if HAVE_SYS_DIR_H
-#    include <sys/dir.h>
-#  endif
-#  if HAVE_NDIR_H
-#    include <ndir.h>
-#  endif
+#include <dirent.h>
 #endif
 
-#if HAVE_STRING_H
 #include <string.h>
-#else
-#include <strings.h>
-#endif
-
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <sys/param.h>
-
-#if STDC_HEADERS
-#  include <stdlib.h>
-#else
-#  if HAVE_MALLOC_H
-#    include <malloc.h>
-#  endif
+#ifndef __FreeBSD__
+#include <malloc.h>
 #endif
+#include <stdlib.h>
+
 
 #include "options.h"
 #include "mode.h"
@@ -230,11 +212,7 @@ void InitBrowser ()
     br.parse_flag = NO_RECURSIVE;
     br_start = (char *) getenv ( "XCORAL_PARSE_PATH" );
     if ( br_start != 0 ) {
-#if HAVE_GETCWD
 	(void) getcwd ( pathname, MAXPATHLEN );
-#else
-	(void) getwd  ( pathname );
-#endif
 	br.parse_flag = RECURSIVE;
 	ParseDir ( br_start, pathname );
     }
@@ -403,10 +381,12 @@ static void BrowserButtons ()
     XSelectInput ( dpy, br.edit, ExposureMask | ButtonPressMask | ButtonReleaseMask);
     XSelectInput ( dpy, br.close, ExposureMask | ButtonPressMask | ButtonReleaseMask);
     XSelectInput ( dpy, br.rec, ExposureMask | ButtonPressMask | ButtonReleaseMask);
+#ifndef LIONEl
     XSelectInput ( dpy, br.pp, ExposureMask | ButtonPressMask | ButtonReleaseMask);
     XSelectInput ( dpy, br.dump, ExposureMask | ButtonPressMask | ButtonReleaseMask);
     XSelectInput ( dpy, br.restore, ExposureMask | ButtonPressMask | ButtonReleaseMask);
     XSelectInput ( dpy, br.hide, ExposureMask | ButtonPressMask | ButtonReleaseMask);
+#endif    
 }
 
 /*
@@ -439,7 +419,7 @@ void LoadDir ( dir )
 	    buf = dp->d_name;			
 	}
 	else {
-	    buf = (char *) malloc ( (unsigned) (strlen (dir) + NAMLEN(dp) + 4) );
+	    buf = (char *) malloc ( (unsigned) (strlen ( dir ) + strlen ( dp->d_name ) + 4) );
 	    (void) sprintf ( buf, "%s/%s", dir, dp->d_name );
 	}
 	(void) stat ( buf , &st );
