@@ -74,30 +74,41 @@ extern BrowserError add_file        (/* char*      file_name */);
 
 extern BrowserError add_proc        (/* char*      proc_name,
                                         ProcType   proc_type,
-                                        LineNumber impl_line */);
-
-
-/*------------------------------------------------------------------------------
-//
-//------------------------------------------------------------------------------
-*/
+                                        LineNumber impl_line,
+					unsigned   hide */);
 
 extern BrowserError add_class       (/* char*      class_name,
-                                        LineNumber decl_line */);
+                                        LineNumber decl_line,
+					unsigned   hide */);
 
 extern BrowserError add_parent      (/* char*      class_name,
                                         char*      parent_name,
+                                        LineNumber decl_line,
                                         ScopeType  scope */);
 
 extern BrowserError add_method_decl (/* char*      class_name, 
                                         char*      method_name,
                                         ScopeType  scope,
-                                        int        virtual_decl,
-                                        LineNumber decl_line */);
+					int decl,
+                                        LineNumber decl_line,
+					unsigned   hide */);
 
 extern BrowserError add_method_impl (/* char*      class_name,
                                         char*      method_name,
-                                        LineNumber impl_line */);
+                                        LineNumber impl_line,
+					unsigned   hide */);
+
+extern BrowserError add_attribute_decl (/* char*      class_name, 
+                                        char*      attr_name,
+                                        ScopeType  scope,
+					int        decl,
+                                        LineNumber decl_line,
+					unsigned   hide */);
+
+extern BrowserError add_global_impl (/* char*	   global_name,
+				        int	   staticp,
+				        LineNumber impl_line,
+					unsigned   hide */);
 
 
 #endif    /*  BROWSERPARSE_H  */
