@@ -41,20 +41,12 @@
 #include <stdio.h>
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
-
-#if STDC_HEADERS
-#  include <stdlib.h>
-#else
-#  if HAVE_MALLOC_H
-#    include <malloc.h>
-#  endif
+#ifdef __FreeBSD__
+#include <stdlib.h>
+#else /* !__FreeBSD__ */
+#include <malloc.h>
 #endif
-
-#if HAVE_STRING_H
 #include <string.h>
-#else
-#include <strings.h>
-#endif
 
 #include "main_text.h"
 #include "color_area.h"
@@ -744,7 +736,7 @@ void ColorLineInPage ( text, x, y, line, s, n )
     (void) fprintf (stderr,"LIGNE %d n1 = %d\n", line, text -> n1);
     (void) write (1,s,n);
     (void) write (1,"\n",1);
-#endif /* DEBUG */
+#endif DEBUG    
 
     if ( line == text -> n1 + 1 ) {
 	/*
@@ -888,7 +880,7 @@ void ColorLineInPage ( text, x, y, line, s, n )
 	XDrawImageString ( dpy, text -> window, text -> Cgc, x, y, s, n );
 #ifdef DEBUG
 	(void) fprintf (stderr,"\tPas d'elements de couleur\n");
-#endif /* DEBUG */
+#endif DEBUG    
 	return;
     }
     text -> current_ce = tmp;
@@ -900,7 +892,7 @@ void ColorLineInPage ( text, x, y, line, s, n )
     while ( n > 0 ) {
 #ifdef DEBUG
     (void) fprintf (stderr,"tmp = %d pos = %d\n", tmp, pos);
-#endif /* DEBUG */
+#endif DEBUG    
 	if (pos == tmp -> pos) {
 	    /* La position courante est sur un element de couleur */
 	    if (n >= tmp -> len)
