@@ -72,6 +72,7 @@
 #include "shadow.h"
 #include "page.h"
 #include "list_box.h"
+#include "warn_box.h"
 
 extern Display *dpy;
 FBox fs_box;
@@ -276,8 +277,8 @@ char *SelectFileFromBox ( msg )
     char *msg;
 {
     char *s = 0;
-    static char full_path_select [256];
- 
+    static char full_path_select [MAXPATHLEN];
+
     FreezeMenus ();
     if ( msg != 0 ) {
 	if ( strlen ( msg ) > (TITLE_SIZE - 2) ) {
@@ -298,7 +299,7 @@ char *SelectFileFromBox ( msg )
     else
       XMapRaised ( dpy, fs_box.frame );
     
-    s = (char *) InputString ( fs_box.mb_frame,
+    s = (char *) InputString ( fs_box.mb_frame, fs_box.frame, 
 			      fs_box.gc, fs_box.font, "File name : " , 0 );
     if ( (s != 0) && (*s == '~') )
       s = ExpandTildeName ( s );
