@@ -39,12 +39,10 @@
 
 
 #include <stdio.h>
-
-#if HAVE_UNISTD_H
-#  include <sys/types.h>
-#  include <unistd.h>
-#endif
-
+#ifdef UNIXWARE
+#include <unistd.h>
+#include <filehdr.h>
+#endif 
 #include <X11/Xlib.h>
 #include <X11/cursorfont.h>
 #include <X11/Xutil.h>
@@ -54,18 +52,21 @@
 #include <sys/file.h>
 #include <sys/param.h>
 
-#if STDC_HEADERS
-#  include <stdlib.h>
-#else
-#  if HAVE_MALLOC_H
-#    include <malloc.h>
-#  endif
+#ifndef apollo
+#ifdef __FreeBSD__
+#include <stdlib.h>
+#else /* !__FreeBSD__ */
+#include <malloc.h>
+#endif
+#endif
+#include <string.h> 
+#ifdef SVR4
+#include <unistd.h>
+#include <sys/exechdr.h>
 #endif
 
-#if HAVE_STRING_H
-#include <string.h>
-#else
-#include <strings.h>
+#ifdef linux
+#include <unistd.h>
 #endif
 
 #include <errno.h>
@@ -88,8 +89,96 @@
 FCT (static int, CheckFile, (char *path, int *len, Text *text) );
 FCT (static int, IsBinary, (FILE *fd, Text *text, int len) );
 FCT (static void, KillCurrentBuffer, (Text *text, int from) );
-FCT (static char*, MyStrerror,  ( int err ) );
 
+/*
+#ifdef sun
+#define _SUN_OS
+#include <sys/exec.h>
+#define ISMAG(x) (((x) == OMAGIC) || ((x) == NMAGIC) || ((x) == ZMAGIC))
+#endif
+
+#ifdef apollo
+#define _APOLLO
+#include <filehdr.h>
+#define ISMAG(x) ISCOFF(x)
+#endif
+
+#if  (m68k && _AUX_SOURCE)
+#define _APPLE_A_UX
+#include <filehdr.h>
+#define ISMAG(x) (((x)==MC68MAGIC) || ((x)==MC68TVMAGIC) || ((x)==M68MAGIC) || ((x)==M68TVMAGIC) \
+|| ((x)==M68NSMAGIC))
+#endif
+
+#ifdef hpux
+#define _HPUX
+*/
+    /*
+       needed to include storage size of 'struct header' below.
+       HP Apollo Series 400 complains otherwise - vetter@hrz.th-darmstadt.de
+    */
+/*
+#define __hp9000s800 
+
+#include <filehdr.h>
+#define ISMAG(x) (((x) == RELOC_MAGIC) || ((x) == EXEC_MAGIC) || ((x) == SHARE_MAGIC) \
+	|| ((x) == DEMAND_MAGIC) || ((x) == DL_MAGIC) || ((x) == SHL_MAGIC))
+#endif
+
+#if ((__osf__) && (__alpha))
+#define _DEC_OSF
+#include <sys/exec.h>
+#define ISMAG(x) (((x) == OMAGIC) || ((x) == NMAGIC) || ((x) == ZMAGIC))
+#endif
+
+#if ((ultrix) && (mips))
+#define _DEC_ULTRIX
+#include <sys/exec.h>
+#define ISMAG(x) (((x) == OMAGIC) || ((x) == NMAGIC) || ((x) == ZMAGIC))
+#endif
+
+#ifdef _AIX
+#include <filehdr.h>
+#define ISMAG(x) (((x) == U802WRMAGIC) || ((x) == U802ROMAGIC) || \
+	((x) == U802TOCMAGIC) || ((x) == U800WRMAGIC) || \
+	((x) == U800ROMAGIC)  || ((x) == U800TOCMAGIC))
+#endif
+
+#if ((sgi) || (__sgi))
+#define _SGI
+#include <filehdr.h>
+#define ISMAG(x) ISCOFF(x)
+#endif
+
+#ifdef linux
+#define _LINUX
+#include <unistd.h>
+#include <a.out.h>
+#define ISMAG(x) (((x)==OMAGIC)||((x)==NMAGIC)||((x)==ZMAGIC))
+#endif
+
+#if defined (__NetBSD__) || defined (__FreeBSD__)
+#define _NETBSD
+#include <a.out.h>
+#define ISMAG(x) (((x) == OMAGIC) || ((x) == NMAGIC) || ((x) == ZMAGIC))
+#endif
+
+#ifdef __bsdi__
+#define _BSDI
+#include <a.out.h>
+#define ISMAG(x) (((x) == OMAGIC) || ((x) == NMAGIC) || ((x) == ZMAGIC))
+#endif
+
+#ifdef UNIXWARE
+#include <sys/x.out.h>
+#define ISMAG(x) (((x) == OMAGIC) || ((x) == NMAGIC) || ((x) == ZMAGIC))
+#endif
+
+#ifndef ISMAG
+#define _BAD_SYS
+#define ISMAG(x) (((x) == OMAGIC) || ((x) == NMAGIC) || ((x) == ZMAGIC))
+#endif
+*/
 extern 	Display	*dpy;
 
 #define MAX_NAME_LEN 20
@@ -333,11 +422,8 @@ void SetDirAndFilename ( text, name )
 	*p1 = 0;
 	chdir(text -> filename);
 
-#if HAVE_GETCWD
 	(void) getcwd ( pathname, MAXPATHLEN );
-#else
-	(void) getwd  ( pathname );
-#endif
+
 	(void) strcpy( text -> current_dir, pathname);
 	if ( strcmp ( text -> current_dir, "/" ) == 0 )
 	  (void) sprintf ( text -> filename, "/%s", p+1 );
@@ -352,11 +438,7 @@ void SetDirAndFilename ( text, name )
 	 * A cause de l'automount et des liens symboliques il faut
 	 * de nouveau verifier le path.
 	 */
-#if HAVE_GETCWD
 	(void) getcwd ( pathname, MAXPATHLEN );
-#else
-	(void) getwd  ( pathname );
-#endif
 
 	if ( strcmp ( pathname, text -> current_dir ) != 0 ) {
 	  (void) strcpy ( text -> current_dir, pathname );
@@ -439,12 +521,17 @@ void WriteFile ( text )
 {
     FILE *fd;
     int size;
+#ifndef __FreeBSD__
+#if !defined(__FreeBSD__) && !defined(__NetBSD__)
+    extern char *sys_errlist[];
+#endif
+#endif
     char buf [2*MAXPATHLEN];
     char *name;
     
     write_flag = True;
     if ( (fd = fopen ( text -> filename, "w" )) == 0 ) {
-	DisplayMessage ( text -> mwin, MyStrerror(errno) );
+	DisplayMessage ( text -> mwin, sys_errlist[errno] );
 	write_flag = False;
 	return;
     }
@@ -593,6 +680,99 @@ static int IsBinary ( fd, text, len )
     Text *text;
     int len;
 {
+/*  
+    unsigned short magic;
+#ifdef _SUN_OS
+    struct exec head;
+#endif
+#ifdef _HPUX
+    struct header head;
+#endif
+#ifdef _DEC_OSF
+    struct exec head;
+#endif
+#ifdef _DEC_ULTRIX
+    struct exec head;
+#endif
+#ifdef _APPLE_A_UX
+    struct filehdr head;
+#endif
+#ifdef _AIX
+    struct filehdr head;
+#endif
+#ifdef _SGI
+    struct filehdr head;
+#endif
+#ifdef _APOLLO
+    struct filehdr head;
+#endif
+#ifdef _LINUX
+    struct exec head;
+#endif
+
+#ifdef _NETBSD
+        struct exec head;
+#endif
+
+#ifdef _BSDI
+	struct exec head;
+#endif
+    
+#ifdef _BAD_SYS
+    struct exec head;
+#endif
+
+#ifdef UNIXWARE
+    struct filehdr head;
+#endif
+    
+    if ( len < sizeof (head) )
+      return False;
+    if (fread((char *) &head, sizeof (head), 1, fd) != 1) {
+	(void) fprintf ( stderr, "Header read error\n" );
+	return False;
+    }
+#ifdef _SUN_OS
+    magic = head.a_magic;
+#endif
+#ifdef _DEC_ULTRIX
+    magic = head.ex_o.magic;
+#endif
+#ifdef _DEC_OSF
+    magic = head.ex_o.magic;
+#endif
+#ifdef _HPUX
+    magic = head.a_magic;
+#endif
+#ifdef _APPLE_A_UX
+    magic = head.f_magic;
+#endif
+#ifdef _SGI
+    magic = head.f_magic;
+#endif
+#ifdef _AIX
+    magic = head.f_magic;
+#endif
+#ifdef _APOLLO
+    magic = head.f_magic;
+#endif
+#ifdef _LINUX
+    magic = (short) head.a_info;
+#endif
+#ifdef _BSDI
+	magic = head.a_magic;
+#endif
+#ifdef _NETBSD
+        magic = N_GETMAGIC (head);
+#endif
+
+    if ( ISMAG (magic) 
+	|| (!strncmp ( (char *) &head, (char *) "!<arch>", 6)) ) {
+	DisplayMessage  ( text -> mwin, "%@#7&^/_!...brrr..." );
+	return True;
+    }
+    return False ;
+*/
   return False;
 }
 
@@ -846,6 +1026,11 @@ int SaveCurrentBuffer ( text, from )
     char c = '\007'; /* ^G */
     char *buf, *name;
     char tmp_name [MAXPATHLEN];
+#ifndef __FreeBSD__
+#if !defined(__FreeBSD__) && !defined(__NetBSD__)
+    extern char *sys_errlist[];
+#endif
+#endif
 
     if (text -> selection -> select == True) {
       SetCurrentLine (text);
@@ -874,7 +1059,7 @@ int SaveCurrentBuffer ( text, from )
 	if ( (str == 0) || ((strncmp(str,"y",1) == 0)&&(strlen(str)==1)) ) {
 	    WriteFile ( text );
 	    if (write_flag != True) {
-	      DisplayWMessage ( MyStrerror(errno), "Save current buffer", True );
+	      DisplayWMessage ( sys_errlist[errno], "Save current buffer", True );
 	      if ( buf != 0 )
 		(void) free ( buf );
 	      return False;
@@ -1204,33 +1389,3 @@ void KbdBrowserRestore ( text )
     TextCursorOn ( text );
 }
 
-
-/*---------------------------------------------------------------------
-*/
-static char*
-MyStrerror ( err )
-    int err;
-{
-#if HAVE_STRERROR
-   return strerror ( err );
-#elif HAVE_SYSERR || HAVE_STDIO_SYSERR
-#  if !HAVE_STDIO_SYSERR
-   extern char *sys_errlist[];
-   extern int sys_nerr;
-#  endif
-   static char buffer[32];
-   if (!err)
-     return "";
- 
-   if ((err > 0) && (err < sys_nerr))
-     return (char*) sys_errlist[err];
- 
-   sprintf (buffer, "Unknown error : %d", err);
-   return buffer;
-#else
-#if HAVE_PERROR
-   perror("System error in xcoral excution");
-#endif
-   return("<<< Error message unavailble >>>");
-#endif
-}
