@@ -44,8 +44,7 @@
 #include <X11/Xutil.h>
 #include <X11/keysym.h>
 #include <ctype.h>
-
-#if HAVE_STRING_H
+#if defined(SYSV) || defined(UNIXWARE) || defined(SVR4)
 #include <string.h>
 #else
 #include <strings.h>
