@@ -41,12 +41,7 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-
-#if HAVE_STRING_H
 #include <string.h>
-#else
-#include <strings.h>
-#endif
 
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
