@@ -39,30 +39,14 @@
 
 
 #include <stdio.h>
+#ifdef __NetBSD__
 #include <pwd.h>
-
-#if HAVE_STRING_H
+#include <dirent.h>
+#else
+#include <dirent.h>
+#include <pwd.h>
+#endif
 #include <string.h>
-#else
-#include <strings.h>
-#endif
-
-#if HAVE_DIRENT_H
-#  include <dirent.h>
-#  define NAMLEN(dirent) strlen((dirent)->d_name)
-#else
-#  define dirent direct
-#  define NAMLEN(dirent) (dirent)->d_namlen
-#  if HAVE_SYS_NDIR_H
-#    include <sys/ndir.h>
-#  endif
-#  if HAVE_SYS_DIR_H
-#    include <sys/dir.h>
-#  endif
-#  if HAVE_NDIR_H
-#    include <ndir.h>
-#  endif
-#endif
 
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
@@ -766,7 +750,7 @@ static char * ExpandFileName (s, n, common)
     while ((entry = readdir(dp)))
       if (strstr(entry->d_name, s) == entry->d_name) {
 	char * nresult =
-	  (char *) malloc((unsigned int) rlength + NAMLEN(entry) + 1 + 1);
+	  (char *) malloc((unsigned int) rlength + strlen(entry->d_name) + 1 + 1);
 	
 	if (! nresult) {
 	    (void) closedir (dp);
@@ -776,11 +760,11 @@ static char * ExpandFileName (s, n, common)
 	
 	bcopy(result, nresult, rlength);
 	(void) strcpy(nresult + rlength, entry->d_name);
-	rlength += NAMLEN(entry) + 1;
+	rlength += strlen(entry->d_name) + 1;
 	*n += 1;
 	{
 	  struct stat st;
-	  char * f = malloc(strlen(current_dir) + 1 + NAMLEN(entry) + 1);
+	  char * f = malloc(strlen(current_dir) + 1 + strlen(entry->d_name) + 1);
 	  
 	  if (f) {
 	    sprintf(f, "%s/%s", current_dir, entry->d_name);
