@@ -255,7 +255,7 @@ static void fPart()
   
   title[0] = '|';
   title[1] = title[2] = ' ';
-  while (title[lg++] = fgetc(fpdtex));
+  while ((title[lg++] = fgetc(fpdtex)) != 0);
   title[lg - 1] = ' ';
   title[lg++] = ' ';
   title[lg++] = '|';
@@ -305,7 +305,6 @@ static void fPart()
 
 static void fChapter()
 {
-  int c;
   int lg = 3;
   int width, twidth, chwidth;
   int marge, nminus, inwidth;
@@ -317,7 +316,7 @@ static void fChapter()
   
   title[0] = '|';
   title[1] = title[2] = ' ';
-  while (title[lg++] = fgetc(fpdtex));
+  while ((title[lg++] = fgetc(fpdtex)) != 0);
   title[lg - 1] = ' ';
   title[lg++] = ' ';
   title[lg] = 0;
@@ -388,15 +387,14 @@ static int souligner(strlen, cwidth, lastchar)
 
 static void fSection()
 {
-  int c;
   int i;
   char title[64];
 
   insert_empty_lines(2);
   
   sprintf(title, "%d.%d       ", ChapterNumber, ++SectionNumber);
-  for (i = 8; title[i] = fgetc(fpdtex); )
-    i += 1;
+  for (i = 8; (title[i] = fgetc(fpdtex)) != 0; i += 1)
+    ;
   
   InsertNchar(TextBuf, title, i);InsertNchar(TextBuf, "\n", 1);
   for (i = souligner(XTextWidth(OutFont, title, i), EqualWidth, title[i-1]);
@@ -418,7 +416,6 @@ static void fSection()
 
 static void fSubSection()
 {
-  int c;
   int i;
   char title[64];
 
@@ -426,8 +423,7 @@ static void fSubSection()
   
   sprintf(title, "%d.%d.%d  ",
 	  ChapterNumber, SectionNumber, ++SubSectionNumber);
-  for (i = strlen(title); title[i] = fgetc(fpdtex); )
-    i += 1;
+  for (i = strlen(title); (title[i] = fgetc(fpdtex)) != 0; i += 1);
   
   InsertNchar(TextBuf, title, i); InsertNchar(TextBuf, "\n", 1);
   for (i = souligner(XTextWidth(OutFont, title, i), MinusWidth, title[i-1]);
@@ -452,7 +448,7 @@ static void fSubSubSection()
 
   insert_empty_lines(1);
   
-  while (title[i] = fgetc(fpdtex))
+  while ((title[i] = fgetc(fpdtex)) != 0)
     i += 1;
   if (i) {
     InsertNchar(TextBuf, title, i);
@@ -519,7 +515,7 @@ static void fBeginTabular()
 
   /* nbre de col et les | */
   iprof = 0;
-  while (profile[iprof] = fgetc(fpdtex))
+  while ((profile[iprof] = fgetc(fpdtex)) != 0)
     cwidth[iprof++] = 0;
 
   /* memorisation */
@@ -570,7 +566,7 @@ static void fBeginTabular()
       default:
 	fprintf(stderr, "tabular{..%c..}\n", profile[iprof - 1]);
       case 'l':
-	while (((ch = contents[c++]) != '\n') && ch)
+	while (((ch = contents[c++] & 255) != '\n') && ch)
 	  if (ch == ConstantSpace) {
 	    *pLine++ = ch;
 	    LineWidth += SpaceWidth;
@@ -616,7 +612,7 @@ static void findex(ln)
   {
     char * pname = name;
     
-    while (*pname++ = fgetc(fpdtex));
+    while ((*pname++ = fgetc(fpdtex)) != 0) ;
   }
   if (IndexNEntry == IndexTabSize) {
     int * newln = (int *) malloc(IndexTabSize * sizeof(int) * 2);
@@ -874,7 +870,6 @@ static void init_justifier()
   
   {
     int i;
-    unsigned char c;
   
     for (i = 0; i != 256; i += 1) {
       unsigned char c = i;
