@@ -41,14 +41,8 @@
 #include <stdio.h>
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
-#include <sys/param.h>
-
-#if HAVE_STRING_H
 #include <string.h>
-#else
-#include <strings.h>
-#endif
-
+#include <sys/param.h>
 
 #include "xcoral.h"
 #include "options.h"
