@@ -99,7 +99,7 @@ Buf *GetBuffer ( size )
        * Alloue la place necessaire pour le buffer.
     */
     if ( size <= 0 ) size = SIZEOF_BUFFER;
-    buf -> top = ( char * ) malloc ( size );
+    buf -> top = ( char * ) malloc ( size + 2);
     if ( buf -> top == 0 ) 
       return ( ( Buf *) 0 );
     /*
@@ -182,7 +182,7 @@ static void MoreBuffer ( buf, n )
     /*
        * Le nouveau buffer
     */
-    if ( (b = ( char * ) malloc ( (unsigned) size )) == 0 )
+    if ( (b = ( char * ) malloc ( (unsigned) size + 2)) == 0 )
       (void) fprintf ( stderr, "Malloc error\n" );
     
     /* 
@@ -317,7 +317,7 @@ int WriteCurrentFile ( buf, fd )
 	(void) fprintf ( stderr, "l_size = %d\n", l_size );
 #endif
 	if ( fwrite ( buf -> top, l_size, 1, fd ) != 1 ) {
-	    perror ( "Write error\n" );
+/*	    perror ( "Write error\n" );*/
 	    return (-1);
 	}
     }
@@ -329,7 +329,7 @@ int WriteCurrentFile ( buf, fd )
 	(void) fprintf ( stderr, "r_size = %d\n", r_size );
 #endif
 	if ( fwrite ( buf -> r_cur + 1, r_size, 1, fd ) != 1 ) {
-	    perror ( "Write error\n" );
+/*	    perror ( "Write error\n" ); */
 	    return (-1);
 	}
     }
