@@ -44,7 +44,7 @@
 #include <sys/types.h>
 #include <fcntl.h>
 #include <sys/time.h>
-#ifdef HAVE_SYS_SELECT_H
+#ifdef _AIX
 #include <sys/select.h>
 #endif
 
@@ -109,17 +109,9 @@ static Text *lock_buttons = 0;
 Window w_sel = None;
 Atom prop_sel;
 jmp_buf br_env;
+fd_set readfds, save_readfds; 
 int width_fd;
 
-fd_set readfds, save_readfds;
-
-#if defined(fd_set)
-#define FD_SET(n, p)    ((*p) |= (1 << (n)))
-#define FD_CLR(n, p)    ((*p) &= ~(1 << (n)))
-#define FD_ISSET(n, p)  ((*p) & (1 << (n)))
-#define FD_ZERO(p)      ((*p) = 0)
-#endif
-
 /*
 **	Function name : InitEvent
 **
@@ -160,7 +152,7 @@ void InitEvent ()
 */
 void WaitForEvent ()
 {
-#if HAVE_SIGPROCMASK
+#if defined(SVR4) || defined(UNIXWARE)
 	sigset_t block, oblock;
 #else
     int old_mask;
@@ -175,7 +167,7 @@ void WaitForEvent ()
     for (;;) {
 	while ( XPending ( dpy ) == 0 ) {
 	    /* Pour un ^C eventuel */
-#if HAVE_SIGPROCMASK
+#if defined(SVR4) || defined(UNIXWARE)
 		(void)sigemptyset(&block);
 		(void)sigaddset(&block, SIGINT);
 		if (sigprocmask(SIG_BLOCK, &block, &oblock) < 0)
@@ -208,7 +200,7 @@ void WaitForEvent ()
 	      }
 	      break;
 	    }
-#if HAVE_SIGPROCMASK
+#if defined(SVR4) || defined(UNIXWARE)
 		(void)sigprocmask(SIG_SETMASK, &oblock, (sigset_t *)NULL);
 #else
 		(void) sigsetmask(old_mask);
@@ -931,7 +923,6 @@ void HandleButtonPress ()
 		  }
 		}
 	      }
-	      TextCursorOn ( edwin -> text );
 	      (void) BrowserClearSelection();
 	      w_sel = ev -> xbutton.window;
 	      XSetSelectionOwner ( dpy, XA_PRIMARY, w_sel, ev -> xbutton.time);
