@@ -44,19 +44,14 @@
 #include <sys/types.h>
 #include <sys/time.h>
 #include <signal.h>
-
-#if HAVE_STRING_H
 #include <string.h>
-#else
-#include <strings.h>
-#endif
 
-#if STDC_HEADERS
-#  include <stdlib.h>
-#else
-#  if HAVE_MALLOC_H
-#    include <malloc.h>
-#  endif
+#ifndef apollo
+#ifdef __FreeBSD__
+#include <stdlib.h>
+#else /* !__FreeBSD__ */
+#include <malloc.h>
+#endif
 #endif
 
 #include "xcoral.h"
