@@ -42,12 +42,7 @@
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
 #include <X11/cursorfont.h>
-
-#if HAVE_STRING_H
 #include <string.h>
-#else
-#include <strings.h>
-#endif
 
 #include "xcoral.h"
 #include "main_text.h"
@@ -60,7 +55,7 @@
 #include "text_cursor.h"
 #include "shadow.h"
 #include "bm_search.h"
-
+
 extern Display *dpy;
 MBox man_box;
 static  Atom man_del;
