@@ -51,12 +51,12 @@
 #include "input_str.h"
 #include "dial_box.h"
 #include "get_file.h"
+#include "kill_buf.h"
+#include "selection.h"
 
 /* #define DEBUG */
 
-
 extern Display *dpy;
-extern void StoreInKillBuf ();
 
 FCT (static void, AfterMarkOnCurrent, (Text *text, int len, int lines) );
 FCT (static int, BeforeMarkOnCurrent, (Text *text, int len, int lines) );
@@ -545,8 +545,11 @@ static void SmallRegion ( text, op )
     char buf [32];
     
     /*
-	* La marque et le curseur sont sur la meme ligne
-	*/
+     * La marque et le curseur sont sur la meme ligne
+    */
+    if (text -> selection -> select == True)
+      ClearSelection(text, True);
+    
     TextCursorOff ( text );
     diff = text -> markpos - GetNcFromLeft ( text -> buf );
 
@@ -556,7 +559,7 @@ static void SmallRegion ( text, op )
     }
     else if ( diff > 0 ) {
 	/* curseur avant la marque */
-	StoreInKillBuf ( RightBuf ( text -> buf ) , diff, 0 ); 
+      StoreInKillBuf ( RightBuf ( text -> buf ) , diff, 0 );
 	if ( op == KILLREGION ) {
 	    StoreInUndo ( text, RightBuf ( text -> buf ), (char *) 0, -diff , 0, U_STD );
     
@@ -569,13 +572,13 @@ static void SmallRegion ( text, op )
 	    DeleteNchar ( text -> buf, diff );
 	}
 	else {
-	    (void) sprintf ( buf, "%d bytes copied", diff );
-	    DisplayMessage ( text -> mwin, buf );
+	  (void) sprintf ( buf, "%d bytes copied", diff );
+	  DisplayMessage ( text -> mwin, buf );
 	}
     }
     else { /* diff < 0 */
 	/* curseur apres la marque */
-	StoreInKillBuf ( LeftBuf ( text -> buf ) + diff + 1, - diff, 0 ); 
+      StoreInKillBuf ( LeftBuf ( text -> buf ) + diff + 1, - diff, 0 );
 	if ( op == KILLREGION ) {
 	    (void) MoveHole ( text -> buf, diff ); 
 	    StoreInUndo ( text, RightBuf ( text -> buf ) , (char *) 0, diff , 0, U_STD );
@@ -613,9 +616,12 @@ static void BigRegion ( text, op )
 {
     int diff, lines;
     int len;
-    char buf [32];
     char *p;
+    char buf [32];    
     
+    if (text -> selection -> select == True)
+      ClearSelection(text, True);
+
     if ( (lines = text -> no_current_line - text -> markline) > 0 ) 
       (void) GetBackwardLine ( text -> buf, -lines, &len );
     else
@@ -624,12 +630,12 @@ static void BigRegion ( text, op )
     if ( (diff = len + text -> markpos) < 0 )
       diff *= -1;
     
-    if ( lines > 0 ) { /* Curseur apres la marque */
-	  StoreInKillBuf ( LeftBuf ( text -> buf ) - diff + 1, diff, lines );
-    }
-    else {
+      if ( lines > 0 ) { /* Curseur apres la marque */
+	StoreInKillBuf ( LeftBuf ( text -> buf ) - diff + 1, diff, lines );
+      }
+      else {
 	StoreInKillBuf ( RightBuf ( text -> buf ) , diff, -lines );
-    }
+      }
     
     if ( op == KILLREGION ) {
 	StorePosition(text);
@@ -650,7 +656,6 @@ static void BigRegion ( text, op )
 	text -> lines_in_buf = GetNumberOfLineInBuf ( text -> buf ); 
 	SetScrollLine ( text -> swin , text -> lines_in_buf );
 	SetScrollBarSize ( dpy, text -> swin );
-/*	CurrentLineToMiddle ( text );  */
 	SetPosition(text);
 	UpdatePage(text);
     }
@@ -669,7 +674,9 @@ static void BigRegion ( text, op )
 	/* Pour la couleur */
 	if ( text -> current_ce != 0 ) {
 	  (void) UpdateColorList ( text, -diff );
+	  ClipOn ( text, 0 );
 	  RefreshPage(text);
+	  ClipOff ( text );
 	}
 	
 	SetTextModif ( text);
@@ -688,7 +695,7 @@ static void BigRegion ( text, op )
 void PasteRegion ( text )
     Text *text;
 {
-    Control_Y ( text, 0 );	
+  Control_Y ( text, 0 );
 }
 
 /*
@@ -757,7 +764,6 @@ void IndentRegion ( text )
   text = update_cwd(nw);
   if ( msg != 0 )
     DisplayMessage ( text -> mwin, msg );
-/*  SetPosition ( text ); */
   ie_redisplay ( text );
 }      
 
@@ -780,7 +786,6 @@ void EvalRegion ( text )
     
     if ( msg != 0 )
       DisplayMessage ( text -> mwin, msg );
-/*    SetPosition ( text ); */
     ie_redisplay ( text );
 }      
 
@@ -850,6 +855,11 @@ void EvalExpressionFromMenu ( text )
     char *str;
     char c = '\007'; /* ^G */
     
+    if (text -> selection -> select == True) {
+      SetCurrentLine (text);
+      ClearSelection(text, True);
+    }
+
     StorePosition ( text );
     SetMBcontext ( CTX_EVAL_EXP );
     str = (char *) GetStringFromDB ( "Eval expression : ", False );
@@ -874,6 +884,8 @@ void ColorRegion(text)
     Text *text;
 {
   char *msg;
+
+  StorePosition (text);
   msg = (char *) ie_call_function ( text, "color_region", 0, 0);
   if ( msg != 0 )
     DisplayMessage ( text -> mwin, msg );
@@ -891,9 +903,224 @@ void ColorBuffer(text)
     Text *text;
 {
   char *msg;
+
+  StorePosition (text);
   msg = (char *) ie_call_function ( text, "color_buffer", 0, 0);
   if ( msg != 0 )
     DisplayMessage ( text -> mwin, msg );
   ie_redisplay ( text );
 }
 
+/*
+**	Function name : Yank
+**
+**	Description :
+**	Input :
+**	Output :
+*/
+void Yank(text)
+    Text *text;
+{
+    Control_Y (text,0);
+}
+
+/*
+**	Function name : smac_copy_region
+**
+**	Description :
+**	Input :
+**	Output :
+*/
+void smac_copy_region(text)
+    Text *text;
+{
+  int diff, lines;
+  int len;
+
+  if ( text -> markline == 0 )
+    return;
+  
+  if ( text -> no_current_line == text -> markline ) {
+    /* La marque et le curseur sont sur la meme ligne */
+    diff = text -> markpos - GetNcFromLeft ( text -> buf );
+    
+    if ( diff == 0 )
+      return;
+    
+    else if ( diff > 0 ) {
+      /* curseur avant la marque */
+      StoreInKillBuf(RightBuf(text -> buf), diff, 0); 
+    }
+    else { /* diff < 0 */
+      /* curseur apres la marque */
+      StoreInKillBuf(LeftBuf(text -> buf)+diff+1, -diff, 0);
+    }
+  } 
+  else {
+    if ( (lines = text -> no_current_line - text -> markline) > 0 ) 
+      (void) GetBackwardLine ( text -> buf, -lines, &len );
+    else
+      (void) GetForwardLine ( text -> buf,  -lines, &len );
+    
+    if ( (diff = len + text -> markpos) < 0 )
+      diff *= -1;
+    
+    
+    if (lines > 0)
+      StoreInKillBuf(LeftBuf(text -> buf)-diff+1, diff, lines);
+    else
+      StoreInKillBuf(RightBuf(text -> buf),diff, -lines);
+    
+    text -> markpos = 0;
+    UpdateMarkPos (text);
+  }
+}
+
+/*
+**	Function name : smac_paste_region
+**
+**	Description :
+**	Input :
+**	Output :
+*/
+void smac_paste_region(text)
+    Text *text;
+{
+  int mark = 0;
+  int region_len, region_lines;
+
+  char *p = (char *) RestoreKillBuf ( 0, &region_len, &region_lines );
+ 
+  if ( p == 0 )
+    return;
+
+  ClipOn ( text, 0 );
+  SetTextModif ( text );
+  
+  if ( region_lines == 0 ) {
+    if ( region_len == 1 && *p == '\n' ) {  /* ligne vide */
+	  f_return ( text );
+    }
+    else {
+      UpdateMark ( text, region_len, 0 );
+      InsertNchar ( text -> buf, p, region_len );
+      (void) StoreInUndo ( text, p, (char *) 0, region_len ,0, U_STD );    
+    }
+  }
+  else {
+    mark = UpdateMark (text, region_len, region_lines);
+    InsertNchar (text -> buf, p, region_len);      
+    text -> no_current_line += region_lines;
+    text -> lines_in_buf = GetNumberOfLineInBuf (text -> buf);
+
+    if ( text -> n2 < region_lines ) {
+      if ( text -> no_current_line >= ( text -> lines_in_page / 2 )) { 
+	text -> n1 = text -> lines_in_page / 2;
+	text -> n2 = text -> lines_in_page - text -> n1 - 1;
+      }
+      else {
+	text -> n1 = text -> no_current_line - 1;
+	text -> n2 = text -> lines_in_page - text -> n1 - 1;
+      }
+    }
+    else {
+      text -> n1 += region_lines;
+      text -> n2 -= region_lines;
+    }
+    
+    if (mark) 
+      UpdateMarkPos (text );
+    (void) StoreInUndo ( text, p, (char *) 0, region_len ,region_lines, U_STD ); 
+  }
+}
+
+/*
+**	Function name : smac_kill_region
+**
+**	Description :
+**	Input :
+**	Output :
+*/
+void smac_kill_region(text)
+    Text *text;
+{
+  int diff;
+  int lines;
+  int len;
+  char *p;
+  
+  if ( text -> markline == 0 )
+    return;
+  
+  if ( text -> no_current_line == text -> markline ) {
+    /* La marque et le curseur sont sur la meme ligne */
+    diff = text -> markpos - GetNcFromLeft ( text -> buf );
+    if ( diff == 0 )
+      return;
+    else if ( diff > 0 ) {
+      /* curseur avant la marque */
+      StoreInKillBuf ( RightBuf ( text -> buf ) , diff, 0 );
+      StoreInUndo ( text, RightBuf ( text -> buf ), (char *) 0, -diff , 0, U_STD );
+      
+      /* Pour la couleur */
+      if ( text -> current_ce != 0 )
+	(void) UpdateColorList ( text, -diff );
+      
+      (void) MoveHole ( text -> buf, diff );
+      (void) UpdateMark ( text, -diff, 0 );
+      DeleteNchar ( text -> buf, diff );
+    }
+    else { /* diff < 0 */
+      /* curseur apres la marque */
+      StoreInKillBuf ( LeftBuf ( text -> buf ) + diff + 1, - diff, 0 );
+      (void) MoveHole ( text -> buf, diff ); 
+      StoreInUndo ( text, RightBuf ( text -> buf ) , (char *) 0, diff , 0, U_STD );
+      
+      /* Pour la couleur */
+      if ( text -> current_ce != 0 )
+	(void) UpdateColorList ( text, diff );
+      
+      (void) MoveHole ( text -> buf, -diff );
+      DeleteNchar ( text -> buf, -diff );
+      ResetMark ( text );
+    }
+    SetTextModif ( text);
+  }
+  else {
+    if ( (lines = text -> no_current_line - text -> markline) > 0 ) 
+      (void) GetBackwardLine ( text -> buf, -lines, &len );
+    else
+      (void) GetForwardLine ( text -> buf,  -lines, &len );
+    
+    if ( (diff = len + text -> markpos) < 0 )
+      diff *= -1;
+    if ( lines > 0 ) { /* Curseur apres la marque */
+      StoreInKillBuf ( LeftBuf ( text -> buf ) - diff + 1, diff, lines );
+    }
+    else {
+      StoreInKillBuf ( RightBuf ( text -> buf ) , diff, -lines );
+    }
+    StorePosition(text);
+    if ( lines > 0 ) { /* Curseur apres la marque */ 
+      (void) MoveHole ( text -> buf, -diff ); /* On va a la marque */
+      p = RightBuf ( text -> buf );			
+      (void) MoveHole ( text -> buf, diff ); /* on revient au curseur */
+      ResetMark ( text );
+    }
+    else { /* curseur avant la marque */
+      p = RightBuf ( text -> buf );
+      (void) MoveHole ( text -> buf, diff );
+      (void) UpdateMark ( text, -diff, lines );
+    }
+    DeleteNchar ( text -> buf, diff );
+    if ( lines > 0 )
+      text -> no_current_line -= lines;
+    text -> lines_in_buf = GetNumberOfLineInBuf ( text -> buf ); 
+    text -> markpos = 0;
+    UpdateMarkPos ( text );
+    StoreInUndo ( text, p, (char *) 0, -diff , (lines > 0) ? lines  : -lines, U_STD );
+    if ( text -> current_ce != 0 )
+      (void) UpdateColorList ( text, -diff );
+    SetTextModif ( text);
+  }
+}
