@@ -39,22 +39,14 @@
 
 
 #include <stdio.h>
+#include <string.h>
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
 #include <X11/keysym.h>
-
-#if HAVE_STRING_H
-#include <string.h>
-#else
-#include <strings.h>
-#endif
-
-#if STDC_HEADERS
-#  include <stdlib.h>
-#else
-#  if HAVE_MALLOC_H
-#    include <malloc.h>
-#  endif
+#ifdef __FreeBSD__
+#include <stdlib.h>
+#else /* !__FreeBSD__ */
+#include <malloc.h>
 #endif
 
 #include "xcoral.h"
@@ -136,10 +128,6 @@ FCT (static void, ie_WR_shell_CtrD, (Text *text) );
 FCT (static void, ie_WR_shell_key, (Text *text) );
 FCT (static void, ie_WR_yank, (Text *text) );
 
-#if !HAVE_STRDUP
-extern FCT (char*, strdup, (char*) );
-#endif
-
 /*
 **	Function name : AllocMode
 **
@@ -562,14 +550,22 @@ f2s func_string [NB_BUILTIN_FUNC] = {
 **	Input : 
 **	Ouput :
 */
+#ifdef __alpha
 long GetFuncNameFromString ( s )
+#else
+int GetFuncNameFromString ( s )
+#endif    
     char *s;
 {
     int i = 0;
 
     while ( func_string [i].f != 0 ) {
 	if ( strcmp ( (char *) func_string [i].s, s ) == 0 )
+#ifdef __alpha	  
 	  return ((long) func_string [i].f);
+#else	
+	  return ((int) func_string [i].f);
+#endif	  
 	i++;
     }
     return (0);
