@@ -66,7 +66,11 @@ typedef struct _mode {
 
 FCT (Mode *, CreateNewMode, (char *mode_name) );
 
+#ifdef __alpha
 FCT (long, GetFuncNameFromString, (char *s) );
+#else
+FCT (int, GetFuncNameFromString, (char *s) );
+#endif
 
 FCT (Mode *, GetMode, (char *name) );
 FCT (void, InitMode, () );
