@@ -52,6 +52,7 @@
 #include "shadow.h"
 #include "bm_search.h"
 #include "color_area.h"
+#include "selection.h"
 
 extern Display *dpy;
 
@@ -60,6 +61,8 @@ FCT (static void, ScrollUpFewLines, (Text *text, int n) );
 FCT (static void, ScrollDownFewLines, (Text *text, int n) );
 FCT (static void, ShiftLinesTable, (Text *text, int dir) );
 
+#define S_DELAY 25000
+
 /*
 **	Function name : FirstPage
 **
@@ -78,6 +81,8 @@ void FirstPage ( text )
 #ifdef DEBUG
     (void) fprintf ( stderr,"ht = %d\n", text -> height );
 #endif
+    text -> no_current_line = 1;
+    Display3D ( dpy, text -> window, text -> top_sh, text -> bot_sh, 2, 1 );
     SetAndDisplayPage ( text );
     
     if ( text -> stat & MESSAGE ) {
@@ -86,7 +91,7 @@ void FirstPage ( text )
     }
     
     (void) MoveScrollBar ( dpy, text -> swin, FIRST, 0 );
-    text -> no_current_line = 1;
+/*    text -> no_current_line = 1; */
     
     MSET ( text -> stat, FIRSTPAGE );
     MCLEAR ( text -> stat, LASTPAGE );
@@ -109,9 +114,14 @@ void FirstPage ( text )
 void ClearPage ( text )
     Text *text;
 {
-    XClearArea ( dpy, text -> window,
+/*
+   XClearArea ( dpy, text -> window,
 		text -> x_or, text -> y_or, text -> width - ( 2 * text -> x_or ),
 		text -> height - ( 2 * text -> y_or ), False );
+*/
+  XClearArea ( dpy, text -> window, 0, 0, 
+	      text -> width, text -> height, False );
+  Display3D ( dpy, text -> window, text -> top_sh, text -> bot_sh, 2, 1);
 }
 
 
@@ -238,13 +248,6 @@ void SetLinesTable ( text )
      * celui-ci est global a tous les buffers
      * 
      */
-/*    
-    if (  TextInBuf ( text ) != True ) {
-	text -> page.sline [ text -> n1 + 1 ] = (char *) 0;
-	return;
-    }
-*/    
-    
     for ( line = text -> n1; line > 0 ; line-- ) {
 	if (! s)
 	  s = ( char * ) GetBackwardLine ( text -> buf, -line, &len );
@@ -252,8 +255,13 @@ void SetLinesTable ( text )
 	  while (*s++ != '\n')
 	    ;
 	if ( s ) {
-	    if ( text -> sl )
+	    if ( text -> sl ) {
+	      hs = s;
 	      s = HscrollString ( s, text );
+	      text -> page.hs_dl [wl] = s - hs;
+	    }
+	    else
+	      text -> page.hs_dl [wl] = 0;
 	    text -> page.sline [ wl ] = s;
 	}
 	else {
@@ -261,6 +269,7 @@ void SetLinesTable ( text )
 	    (void) fprintf ( stderr,"sline null wl = %d\n", wl );
 #endif
 	    text -> page.sline [ wl ] = ( char * ) 0;
+	    text -> page.hs_dl [wl] = 0;
 	    n++;
 	    continue;
 	}
@@ -271,31 +280,34 @@ void SetLinesTable ( text )
 	  s = ( char * ) GetCurrentLine ( text -> buf, &len );
 	else if (line == 1)
 	  s = ( char * ) GetForwardLine ( text -> buf, line, &len );
-	else if (s) {
-	  char * b = text -> buf -> bottom;
-	  
-	  while (*s++ != '\n')
-	    if (s >= b)
-	      break;
-
-	  if (s == b) {
-	    if (*s != '\n')
-	      /* ligne sans cr final, appelle GetForwardLine pour ajouter
-	         le cr final (eventuellement dans une ligne static */
-	      s = GetForwardLine ( text -> buf, line, &len );
+	else {
+	  if (s) {
+	    char * b = text -> buf -> bottom;
+	    
+	    while (*s++ != '\n')
+	      if (s >= b)
+		break;
+	    
+	    if (s == b) {
+	      if (*s != '\n')
+		/* ligne sans cr final, appelle GetForwardLine pour ajouter
+		   le cr final (eventuellement dans une ligne static */
+		s = GetForwardLine ( text -> buf, line, &len );
+	    }
+	    else if (s > b)
+	      s = 0;
 	  }
-	  else if (s > b)
-	    s = 0;
-	}
-	
+	}	
 	if ( s ) {
 	    if ( text -> sl ) {
 	      hs = s;
 	      s = HscrollString ( s, text );
+	      text -> page.hs_dl [wl] = s - hs;
 	      if ( line == 0 )
 		text -> page.hs_delta = s - hs;
 	    }
 	    else {
+   	        text -> page.hs_dl [wl] = 0;
 		if (line == 0)
 		  text -> page.hs_delta = 0;  
 	    }
@@ -306,6 +318,7 @@ void SetLinesTable ( text )
 	    (void) fprintf ( stderr,"sline null wl = %d\n", wl );
 #endif
 	    text -> page.sline [ wl ] = ( char * ) 0;
+	    text -> page.hs_dl [wl] = 0;
 	}
 	wl ++;
     }
@@ -342,10 +355,13 @@ void SetCurrentLine ( text )
 	if ( text -> sl ) {
 	  hs = s;
 	  s = (char *) HscrollString ( s, text );
+	  text -> page.hs_dl [line] = s - hs;
 	  text -> page.hs_delta = s - hs;
 	}
-	else
+	else {
+	  text -> page.hs_dl [line] = 0;
 	  text -> page.hs_delta = 0;
+	}
 
 	text -> page.sline [ line ] = s;
 	text -> page.wline [ line ] =  DrawLineOfText ( text, line );
@@ -844,6 +860,7 @@ static void ScrollUpFewLines ( text, n )
 {
     Buf *buf;
     int len;
+    int sel_was_visible = SelectionIsVisible(text);
     
     buf = text -> buf;
 #ifdef DEBUG
@@ -851,21 +868,25 @@ static void ScrollUpFewLines ( text, n )
 #endif
     ClipOn ( text, 0 );
     while ( n ) {
-	(void) ShiftLinesTable ( text, DOWN );
-	text -> page.sline [1] = 
-	  GetBackwardLine ( buf, - ( text -> n1 + 1 ), &len ); 
-
-/*	RefreshPage ( text ); */
-	if ( text -> n2 == 0 ) {
-	    (void) MoveToLine ( buf, -1 );
-	    text -> no_current_line --;
-	}
-	else {
-	    text -> n1 ++;
-	    text -> n2 --;
-	}
-	RefreshPage ( text );
-	n++;
+      (void) ShiftLinesTable ( text, DOWN );
+      text -> page.sline [1] = 
+	GetBackwardLine ( buf, - ( text -> n1 + 1 ), &len ); 
+      
+      if ( text -> n2 == 0 ) {
+	(void) MoveToLine ( buf, -1 );
+	text -> no_current_line --;
+      }
+      else {
+	text -> n1 ++;
+	text -> n2 --;
+      }
+      if (sel_was_visible)
+	(void) ClearPage(text);
+      RefreshPage (text);
+      if ((sel_was_visible = SelectionIsVisible(text)) != 0)
+	(void) RefreshSelection(text);
+      n++;
+      SmallTime(S_DELAY);
     }
     ClipOff ( text );
     
@@ -896,6 +917,7 @@ static void ScrollDownFewLines ( text, n )
 {
     Buf *buf;
     int len;
+    int sel_was_visible = SelectionIsVisible(text);
     
     buf = text -> buf;
 #ifdef DEBUG
@@ -903,21 +925,25 @@ static void ScrollDownFewLines ( text, n )
 #endif
     ClipOn ( text, 0 );
     while ( n ) {
-	(void) ShiftLinesTable ( text, UP );
-	text -> page.sline [text -> lines_in_page] = 
-	  GetForwardLine ( buf, text -> n2 + 1, &len );
-
-/*	RefreshPage ( text ); */
-	if ( text -> n1 == 0 ) {
-	    (void) MoveToLine ( buf, 1 );
-	    text -> no_current_line ++;
-	}
-	else {
-	    text -> n1 --;
-	    text -> n2 ++;
-	}
-	RefreshPage ( text );
-	n--;
+      (void) ShiftLinesTable ( text, UP );
+      text -> page.sline [text -> lines_in_page] = 
+	GetForwardLine ( buf, text -> n2 + 1, &len );
+      
+      if ( text -> n1 == 0 ) {
+	(void) MoveToLine ( buf, 1 );
+	text -> no_current_line ++;
+      }
+      else {
+	text -> n1 --;
+	text -> n2 ++;
+      }
+      if (sel_was_visible)
+	(void) ClearPage(text);
+      RefreshPage (text);
+      if ((sel_was_visible = SelectionIsVisible(text)) != 0)
+	(void) RefreshSelection(text);
+      n--;
+      SmallTime(S_DELAY);
     }
     ClipOff ( text );
     DisplayMessage ( text -> mwin, " " );
@@ -1029,7 +1055,15 @@ void SetAndDisplayPage ( text )
 {
     ClipOn ( text, 0 );
     (void) SetLinesTable ( text );
+
+    if (text-> selection -> select == True)
+      (void) ClearPage (text);
+    
     RefreshPage ( text );
+
+    if (text-> selection -> select == True)
+      (void) RefreshSelection(text);
+    
     ClipOff ( text );
 }
 
