@@ -65,20 +65,15 @@
 #include <X11/cursorfont.h>
 #include <X11/Xutil.h>
 #include <X11/keysym.h>
+#include <string.h>
 #include <pwd.h>
 
-#if HAVE_STRING_H
-#include <string.h>
-#else
-#include <strings.h>
+#ifndef apollo
+#ifdef __FreeBSD__
+#include <stdlib.h>
+#else /* !__FreeBSD__ */
+#include <malloc.h>
 #endif
-
-#if STDC_HEADERS
-#  include <stdlib.h>
-#else
-#  if HAVE_MALLOC_H
-#    include <malloc.h>
-#  endif
 #endif
 
 #include "xc_conf.h"
@@ -816,7 +811,7 @@ static void SetFont ()
 **	Function name : SetGeometry
 **
 **	Description : Initialisation de la geometrie de 
-**		la fenetre principale.
+**		la feneter printcipale.
 **	Input : 
 **	Ouput :
 */
