@@ -55,11 +55,17 @@ struct ProcRec {
   char*           _name;
   FileRec*        _impl_file;
   LineNumber      _impl_line;
-  ProcType        _proc_type;
+#ifndef LIONEl
+  int		  _decl;
+  unsigned	  _hide;
+#endif
   struct ProcRec* _next;
 };
 typedef struct ProcRec ProcRec;
 
+#define STATIC_PROC 1
+#define INLINE_PROC 2
+#define TEMPLATE_PROC 4
 
 /*------------------------------------------------------------------------------
 //                         Le dictionnaire des procedures
