@@ -44,20 +44,15 @@
 #include <sys/types.h>
 #include <sys/time.h>
 #include <signal.h>
+#include <string.h>
 #include <fcntl.h>
 
-#if HAVE_STRING_H
-#include <string.h>
-#else
-#include <strings.h>
+#ifndef apollo
+#ifdef __FreeBSD__
+#include <stdlib.h>
+#else /* !__FreeBSD__ */
+#include <malloc.h>
 #endif
-
-#if STDC_HEADERS
-#  include <stdlib.h>
-#else
-#  if HAVE_MALLOC_H
-#    include <malloc.h>
-#  endif
 #endif
 
 #include "xcoral.h"
@@ -145,12 +140,8 @@ void SetShellMode ( text )
       (void) close ( text -> p_shell [1] );
       (void) close ( text -> p_xc [0] );
       (void) close ( text -> p_xc [1] );
-#if SETPGRP_VOID
-      (void) setpgrp ();
-#else
       c_pid = getpid();
       (void) setpgrp ( c_pid, c_pid);
-#endif
       shell = (char *) getenv("XCORAL_SHELL");
       if (shell == NULL) {
 	shell = (char *) getenv("SHELL");
@@ -159,7 +150,11 @@ void SetShellMode ( text )
 	  strcpy(shell,"/bin/csh");
 	}
       }
+#ifdef linux
+	(void) execlp (shell, shell, "-i", (char *)0);
+#else
       (void) execlp (shell, shell, "-i", 0);
+#endif
       (void) fprintf ( stderr, "Can't exec shell\n" );
       break;
     case -1:
@@ -374,24 +369,14 @@ void shell_CtrC ( text )
     TextCursorOn ( text );
     ClipOff ( text );
     
-#if HAVE_KILL
-# if GETPGRP_VOID
-    (void) kill( - getpgrp(), SIGINT );
-# else
+#if defined(SYSV) || defined(hpux)
     (void) kill( - getpgrp(text -> shell_id), SIGINT );
-# endif
-#elif HAVE_SIGSEND
-# if GETPGRP_VOID
-    (void) sigsend(P_PGID, getpgrp(), SIGINT );
-# else
-    (void) sigsend(P_PGID, getpgrp(text -> shell_id), SIGINT );
-# endif
 #else
-#  if GETPGRP_VOID
-    (void) killpg ( getpgrp(), SIGINT );
-#  else
+#ifdef SVR4 /* also UNIXWARE */
+	(void) sigsend(P_PGID, getpgrp(text -> shell_id), SIGINT );
+#else
     (void) killpg ( getpgrp(text -> shell_id), SIGINT );
-#  endif
+#endif
 #endif
 }
 
@@ -432,12 +417,8 @@ void ReadFromShell ( text )
     int n, lines;
     char tmp [BUFSIZ];
     extern Display *dpy;
-
-#ifdef O_NONBLOCK
-    (void) fcntl ( text -> from_shell, F_SETFL, O_NONBLOCK );
-#else
+    
     (void) fcntl ( text -> from_shell, F_SETFL, O_NDELAY );
-#endif
     n = read ( text -> from_shell, tmp,BUFSIZ );
     if ( n == 0 || n == -1) {
 	/* Ya plus de shell */
