@@ -82,20 +82,23 @@ typedef struct Position Position;
 #define PROC_PLENGTH       7
 
 
-#define PARENT_PREFIX      "[ ]  "
-
-#define PARENT_PLENGTH     5
-
-
 #define METHOD_PREFIX      "[    ]  "
 
 #define METHOD_PLENGTH     8
 
 
-#define CLASS_PREFIX       "[ ]  "
+#define CLASS_PREFIX       "[  ]  "
 
-#define CLASS_PLENGTH      5
+#define CLASS_PLENGTH      6
 
+#define ATTRIBUTE_PREFIX       "[  ]  "
+
+#define ATTRIBUTE_PLENGTH      6
+
+
+#define GLOBAL_PREFIX       "[ ]  "
+
+#define GLOBAL_PLENGTH      5
 
 /*------------------------------------------------------------------------------
 //   Les differentes macros applicable aux resultats retournes par le browser 
@@ -107,15 +110,15 @@ typedef struct Position Position;
 #define GET_PROCEDURE_INFO(pt)  (pt - PROC_PLENGTH)
 #define REMOVE_PROCEDURE_INFO(pt) (pt+PROC_PLENGTH)
 
-#define GET_PARENT_INFO(pt)     (pt - PARENT_PLENGTH)
-#define REMOVE_PARENT_INFO(pt) (pt+PARENT_PLENGTH)
-
-#define GET_SON_INFO(pt)        (pt - CLASS_PLENGTH)
-#define REMOVE_SON_INFO(pt) (pt+SON_PLENGTH)
-
 #define GET_METHOD_INFO(pt)     (pt - METHOD_PLENGTH)
 #define REMOVE_METHOD_INFO(pt) (pt+METHOD_PLENGTH)
 
+#define GET_ATTRIBUTE_INFO(pt)     (pt - ATTRIBUTE_PLENGTH)
+#define REMOVE_ATTRIBUTE_INFO(pt) (pt+ATTRIBUTE_PLENGTH)
+
+#define GET_GLOBAL_INFO(pt)  (pt - GLOBAL_PLENGTH)
+#define REMOVE_GLOBAL_INFO(pt) (pt+GLOBAL_PLENGTH)
+
 #define GET_CLASS_INFO(pt)      (pt - CLASS_PLENGTH)
 #define REMOVE_CLASS_INFO(pt) (pt+CLASS_PLENGTH)
 
@@ -123,5 +126,23 @@ typedef struct Position Position;
 
 extern char* get_method_class();
 
+#define GET_ATTRIBUTE_CLASS(pt)    (get_attribute_class(pt))
+extern char* get_attribute_class();
+
+#define HIDED(pt) ((pt)[-2] == 'H')
+#define HIDE(pt) ((pt)[-2] = 'H')
+#define SHOW(pt) ((pt)[-2] = ' ')
+
+#define UserHide		1
+#define HidePrivate		2
+#define HideProtected		4
+#define HideInherited		8
+#define HideStaticFunctions	16
+#define HideStaticGlobals	32
+#define HideChildrenOf		64
+#define HidenChildren		128
+#define HideInternalTypes	256
+
+extern unsigned	Hide_Bits;
 
 #endif  /*  RESULTTYPES_H  */
