@@ -59,6 +59,10 @@ static char gray [] = { 0x1, 0x02 };
 
 static Pixmap	pix;
 static Cursor   cursor;
+static unsigned long gray745;
+static unsigned long gray65;
+static unsigned long dimgray;
+static unsigned long gainsboro;
 
 FCT (static int, myrint, (double x) );
 
@@ -74,13 +78,27 @@ FCT (static int, myrint, (double x) );
 void InitScroll ( display )
     Display	*display;
 {
+  int result;
     pix = XCreatePixmapFromBitmapData ( display, 
 				       DefaultRootWindow (display), gray, 2, 2, 
 				       BlackPixel ( display, DefaultScreen (display)),
 				       WhitePixel ( display, DefaultScreen (display)),
 				       DefaultDepth (display, DefaultScreen ( display )));
-    
+
     cursor = XCreateFontCursor ( display, XC_sb_left_arrow );
+
+    gray745 = PixelValue ( display, "gray", &result );
+    if ( result == False )
+      gray745 = BlackPixel ( display, DefaultScreen (display));
+    gray65 = PixelValue ( display, "gray65", &result );
+    if ( result == False )
+      gray65 = WhitePixel ( display, DefaultScreen (display));
+    dimgray = PixelValue ( display, "dimgray", &result );
+    if ( result == False )
+      dimgray = BlackPixel ( display, DefaultScreen (display));
+    gainsboro = PixelValue ( display, "gainsboro", &result );
+    if ( result == False )
+      gainsboro = WhitePixel ( display, DefaultScreen (display));
 }
 
 
@@ -100,8 +118,6 @@ SWin *MakeScroll ( display, parent, x, y )
     int x, y;
 {
     SWin *s;
-    int result;
-    unsigned long pixel;
     
     s = (SWin *) malloc ( (unsigned) sizeof ( SWin )); 
     
@@ -136,23 +152,11 @@ SWin *MakeScroll ( display, parent, x, y )
 	s -> fg = WhitePixel ( display, DefaultScreen (display));
     }
     else {
-	/* Color */
-	pixel = PixelValue ( display, "gray", &result );
-	if ( result == False )
-	  pixel = BlackPixel ( display, DefaultScreen (display));
-	XSetWindowBackground ( display, s -> scroll, pixel );
-	
-	pixel = PixelValue ( display, "gray65", &result );
-	if ( result == False )
-	  pixel = WhitePixel ( display, DefaultScreen (display));
-	XSetWindowBackground ( display, s -> frame, pixel );
-	
-	s -> bg = PixelValue ( display, "gainsboro", &result );
-	if ( result == False )
-	  s -> bg = PixelValue ( display, "white", &result );
-	s -> fg = PixelValue ( display, "dimgray", &result );
-	if ( result == False )
-	  s -> fg = PixelValue ( display, "black", &result );	
+      /* Color */
+      XSetWindowBackground ( display, s -> scroll, gray745 );
+      XSetWindowBackground ( display, s -> frame, gray65 );
+      s -> bg = gainsboro;
+      s -> fg = dimgray;
     }
     return ( s );
 }
@@ -374,9 +378,9 @@ void HandleScrollBar ( display, swin, f )
     while ( XCheckMaskEvent ( display, PointerMotionMask, &event ));
     XDefineCursor ( display, swin -> frame, cursor );
     
-    XGrabPointer ( display, swin -> frame, True, ButtonReleaseMask | PointerMotionMask,
+/*    XGrabPointer ( display, swin -> frame, True, ButtonReleaseMask | PointerMotionMask,
 		  GrabModeAsync, GrabModeAsync, swin -> frame, None, CurrentTime );
-    
+*/    
 #ifdef DEBUG
     fprintf ( stderr, "delta = %.3f f_height = %d s_height = %d\n",
 	     swin -> delta, swin -> f_height, swin -> s_height );
@@ -386,7 +390,7 @@ void HandleScrollBar ( display, swin, f )
 	XNextEvent ( display, &event );
 	switch ( event.type ) {
 	case ButtonRelease:
-	  XUngrabPointer ( display, CurrentTime );
+/*	  XUngrabPointer ( display, CurrentTime ); */
 	  XUndefineCursor ( display, swin -> frame );
 	  swin -> last_y = 0;
 	  swin -> rest = dn;
