@@ -366,8 +366,7 @@ static void video_after_cursor(text)
     Text *text;
 {
 /* #define DEBUG9 */
-/*  if (text -> x_pos > text -> selection -> x_el) { */
-  if (text -> x_pos >= text -> selection -> x_el) {
+  if (text -> x_pos > text -> selection -> x_el) {
     /* vers la droite */
 #ifdef DEBUG9
     (void) fprintf (stderr, "91\n");
@@ -384,11 +383,8 @@ static void video_after_cursor(text)
   }
   else {
     /* vers la gauche */
-/*    
     if ((text -> x_pos + text -> cursor_width) != text -> selection -> x_sl 
 	&& (text -> x_pos + text -> cursor_width) != text -> selection -> x_el){
-*/
-    if (text -> x_pos < text -> selection -> x_el) {
 #ifdef DEBUG9
       (void) fprintf (stderr, "92\n");
 #endif /* DEBUG9 */
@@ -1011,7 +1007,7 @@ static void get_bytes_selection(text)
 #ifdef DEBUG11
       (void) fprintf (stderr, "111 s equal e, sl sup el\n");
 #endif /* DEBUG11 */
-      Store_bytes((char *)(RightBuf(text->buf)/*+1*/),nc/*-1*/);
+      Store_bytes((char *)(RightBuf(text->buf)+1),nc-1);
     }
     else { /* nc<0 */
 #ifdef DEBUG11
@@ -1034,8 +1030,8 @@ static void get_bytes_selection(text)
 	nl--;
       p++;
     }
-/*    if(*start != '\n')
-      start ++; */
+    if(*start != '\n')
+      start ++;
     Store_bytes(start, p - start + text -> selection -> ncfl_sl);
   }
   
