@@ -68,7 +68,7 @@ void CreateRGC ( display )
     GC gc;
     XGCValues gcv;
     unsigned long mask;
-    int screen, result;
+    int screen;
 
     shadow_color = UseColor ();
     
@@ -102,10 +102,10 @@ void CreateRGC ( display )
 	 * color
 	 */
       
-	gcv.foreground = PixelValue ( display, "white", &result);
+	gcv.foreground = WhitePixel ( display, screen );
 	fg_pixel = gcv.foreground;
 	
-	gcv.background = PixelValue ( display, "black", &result);
+	gcv.background = BlackPixel ( display, screen );
 	bg_pixel = gcv.background;
 	
 	gcv.fill_style = FillSolid;
